/* small-set.c generated by valac 0.24.0.16-c045, the Vala compiler
 * generated from small-set.vala, do not modify */

/*
 * Copyright © 2013 Intel Corporation
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors:
 *      Simon McVittie <simon.mcvittie@collabora.co.uk>
 */

#include <glib.h>
#include <glib-object.h>
#include <folks-test.h>
#include <folks/small-set.h>
#include <gee.h>
#include <stdlib.h>
#include <string.h>
#include <folks/small-set-internal.h>


#define TYPE_DIRECT_EQ (direct_eq_get_type ())
#define DIRECT_EQ(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DIRECT_EQ, DirectEq))
#define DIRECT_EQ_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DIRECT_EQ, DirectEqClass))
#define IS_DIRECT_EQ(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DIRECT_EQ))
#define IS_DIRECT_EQ_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DIRECT_EQ))
#define DIRECT_EQ_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DIRECT_EQ, DirectEqClass))

typedef struct _DirectEq DirectEq;
typedef struct _DirectEqClass DirectEqClass;
typedef struct _DirectEqPrivate DirectEqPrivate;

#define TYPE_UINT (uint_get_type ())
#define UINT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_UINT, UInt))
#define UINT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_UINT, UIntClass))
#define IS_UINT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_UINT))
#define IS_UINT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_UINT))
#define UINT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_UINT, UIntClass))

typedef struct _UInt UInt;
typedef struct _UIntClass UIntClass;
typedef struct _UIntPrivate UIntPrivate;

#define TYPE_SMALL_SET_TESTS (small_set_tests_get_type ())
#define SMALL_SET_TESTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SMALL_SET_TESTS, SmallSetTests))
#define SMALL_SET_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SMALL_SET_TESTS, SmallSetTestsClass))
#define IS_SMALL_SET_TESTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SMALL_SET_TESTS))
#define IS_SMALL_SET_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SMALL_SET_TESTS))
#define SMALL_SET_TESTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SMALL_SET_TESTS, SmallSetTestsClass))

typedef struct _SmallSetTests SmallSetTests;
typedef struct _SmallSetTestsClass SmallSetTestsClass;
typedef struct _SmallSetTestsPrivate SmallSetTestsPrivate;
typedef struct _Block1Data Block1Data;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
typedef struct _Block2Data Block2Data;
typedef struct _Block3Data Block3Data;
typedef struct _Block4Data Block4Data;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _DirectEq {
	GObject parent_instance;
	DirectEqPrivate * priv;
	guint u;
};

struct _DirectEqClass {
	GObjectClass parent_class;
};

struct _UInt {
	GObject parent_instance;
	UIntPrivate * priv;
	guint u;
};

struct _UIntClass {
	GObjectClass parent_class;
};

struct _SmallSetTests {
	FolksTestCase parent_instance;
	SmallSetTestsPrivate * priv;
};

struct _SmallSetTestsClass {
	FolksTestCaseClass parent_class;
};

struct _Block1Data {
	int _ref_count_;
	SmallSetTests* self;
	guint sum;
	UInt* ten;
};

struct _Block2Data {
	int _ref_count_;
	SmallSetTests* self;
	guint sum;
};

struct _Block3Data {
	int _ref_count_;
	SmallSetTests* self;
	guint u;
};

struct _Block4Data {
	int _ref_count_;
	SmallSetTests* self;
	FolksSmallSet* small;
	gint i;
};


static gpointer direct_eq_parent_class = NULL;
static gpointer uint_parent_class = NULL;
static gpointer small_set_tests_parent_class = NULL;

GType direct_eq_get_type (void) G_GNUC_CONST;
enum  {
	DIRECT_EQ_DUMMY_PROPERTY
};
DirectEq* direct_eq_new (guint u);
DirectEq* direct_eq_construct (GType object_type, guint u);
static void direct_eq_finalize (GObject* obj);
GType uint_get_type (void) G_GNUC_CONST;
enum  {
	UINT_DUMMY_PROPERTY
};
UInt* uint_new (guint u);
UInt* uint_construct (GType object_type, guint u);
guint uint_hash_static (UInt* that);
gboolean uint_equals_static (UInt* left, UInt* right);
static void uint_finalize (GObject* obj);
GType small_set_tests_get_type (void) G_GNUC_CONST;
enum  {
	SMALL_SET_TESTS_DUMMY_PROPERTY
};
SmallSetTests* small_set_tests_new (void);
SmallSetTests* small_set_tests_construct (GType object_type);
static void __lambda3_ (SmallSetTests* self);
void small_set_tests_test_objects (SmallSetTests* self, gboolean use_hash);
static void ___lambda3__folks_test_case_test_method (gpointer self);
static void __lambda8_ (SmallSetTests* self);
static void ___lambda8__folks_test_case_test_method (gpointer self);
static void __lambda9_ (SmallSetTests* self);
void small_set_tests_test_iter (SmallSetTests* self, gboolean use_hash);
static void ___lambda9__folks_test_case_test_method (gpointer self);
static void __lambda14_ (SmallSetTests* self);
static void ___lambda14__folks_test_case_test_method (gpointer self);
static void __lambda15_ (SmallSetTests* self);
void small_set_tests_test_readonly (SmallSetTests* self, gboolean use_hash);
static void ___lambda15__folks_test_case_test_method (gpointer self);
static void __lambda18_ (SmallSetTests* self);
static void ___lambda18__folks_test_case_test_method (gpointer self);
static void __lambda19_ (SmallSetTests* self);
void small_set_tests_test_direct (SmallSetTests* self, gboolean use_hash);
static void ___lambda19__folks_test_case_test_method (gpointer self);
static void __lambda20_ (SmallSetTests* self);
static void ___lambda20__folks_test_case_test_method (gpointer self);
static void __lambda21_ (SmallSetTests* self);
void small_set_tests_test_strings (SmallSetTests* self, gboolean use_hash);
static void ___lambda21__folks_test_case_test_method (gpointer self);
static void __lambda22_ (SmallSetTests* self);
static void ___lambda22__folks_test_case_test_method (gpointer self);
void small_set_tests_test_cheating (SmallSetTests* self);
static void _small_set_tests_test_cheating_folks_test_case_test_method (gpointer self);
static Block1Data* block1_data_ref (Block1Data* _data1_);
static void block1_data_unref (void * _userdata_);
static guint _uint_hash_static_gee_hash_data_func (gconstpointer v, gpointer self);
static gboolean _uint_equals_static_gee_equal_data_func (gconstpointer a, gconstpointer b, gpointer self);
static gboolean __lambda4_ (Block1Data* _data1_, UInt* obj);
static gboolean ___lambda4__gee_forall_func (gpointer g, gpointer self);
static gboolean __lambda5_ (Block1Data* _data1_, UInt* obj);
static gboolean ___lambda5__gee_forall_func (gpointer g, gpointer self);
static gboolean __lambda6_ (Block1Data* _data1_, UInt* obj);
static gboolean ___lambda6__gee_forall_func (gpointer g, gpointer self);
static gboolean __lambda7_ (Block1Data* _data1_, UInt* obj);
static gboolean ___lambda7__gee_forall_func (gpointer g, gpointer self);
static Block2Data* block2_data_ref (Block2Data* _data2_);
static void block2_data_unref (void * _userdata_);
static gboolean __lambda10_ (Block2Data* _data2_, UInt* obj);
static gboolean ___lambda10__gee_forall_func (gpointer g, gpointer self);
static gboolean __lambda11_ (Block2Data* _data2_, UInt* obj);
static gboolean ___lambda11__gee_forall_func (gpointer g, gpointer self);
static gboolean __lambda12_ (Block2Data* _data2_, UInt* obj);
static gboolean ___lambda12__gee_forall_func (gpointer g, gpointer self);
static gboolean __lambda13_ (Block2Data* _data2_, UInt* obj);
static gboolean ___lambda13__gee_forall_func (gpointer g, gpointer self);
static Block3Data* block3_data_ref (Block3Data* _data3_);
static void block3_data_unref (void * _userdata_);
static gboolean __lambda16_ (Block3Data* _data3_, UInt* obj);
static gboolean ___lambda16__gee_forall_func (gpointer g, gpointer self);
static gboolean __lambda17_ (Block3Data* _data3_, UInt* obj);
static gboolean ___lambda17__gee_forall_func (gpointer g, gpointer self);
static Block4Data* block4_data_ref (Block4Data* _data4_);
static void block4_data_unref (void * _userdata_);
static gboolean __lambda23_ (Block4Data* _data4_, UInt* obj);
static gboolean ___lambda23__gee_forall_func (gpointer g, gpointer self);
gint _vala_main (gchar** args, int args_length1);


DirectEq* direct_eq_construct (GType object_type, guint u) {
	DirectEq * self = NULL;
	guint _tmp0_ = 0U;
#line 29 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	self = (DirectEq*) g_object_new (object_type, NULL);
#line 31 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp0_ = u;
#line 31 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	self->u = _tmp0_;
#line 29 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	return self;
#line 229 "small-set.c"
}


DirectEq* direct_eq_new (guint u) {
#line 29 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	return direct_eq_construct (TYPE_DIRECT_EQ, u);
#line 236 "small-set.c"
}


static void direct_eq_class_init (DirectEqClass * klass) {
#line 25 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	direct_eq_parent_class = g_type_class_peek_parent (klass);
#line 25 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	G_OBJECT_CLASS (klass)->finalize = direct_eq_finalize;
#line 245 "small-set.c"
}


static void direct_eq_instance_init (DirectEq * self) {
}


static void direct_eq_finalize (GObject* obj) {
	DirectEq * self;
#line 25 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_DIRECT_EQ, DirectEq);
#line 25 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	G_OBJECT_CLASS (direct_eq_parent_class)->finalize (obj);
#line 259 "small-set.c"
}


GType direct_eq_get_type (void) {
	static volatile gsize direct_eq_type_id__volatile = 0;
	if (g_once_init_enter (&direct_eq_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (DirectEqClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) direct_eq_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (DirectEq), 0, (GInstanceInitFunc) direct_eq_instance_init, NULL };
		GType direct_eq_type_id;
		direct_eq_type_id = g_type_register_static (G_TYPE_OBJECT, "DirectEq", &g_define_type_info, 0);
		g_once_init_leave (&direct_eq_type_id__volatile, direct_eq_type_id);
	}
	return direct_eq_type_id__volatile;
}


UInt* uint_construct (GType object_type, guint u) {
	UInt * self = NULL;
	guint _tmp0_ = 0U;
#line 40 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	self = (UInt*) g_object_new (object_type, NULL);
#line 42 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp0_ = u;
#line 42 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	self->u = _tmp0_;
#line 40 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	return self;
#line 286 "small-set.c"
}


UInt* uint_new (guint u) {
#line 40 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	return uint_construct (TYPE_UINT, u);
#line 293 "small-set.c"
}


guint uint_hash_static (UInt* that) {
	guint result = 0U;
	UInt* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
#line 45 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	g_return_val_if_fail (that != NULL, 0U);
#line 47 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp0_ = that;
#line 47 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp1_ = _tmp0_->u;
#line 47 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	result = _tmp1_;
#line 47 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	return result;
#line 311 "small-set.c"
}


gboolean uint_equals_static (UInt* left, UInt* right) {
	gboolean result = FALSE;
	UInt* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
	UInt* _tmp2_ = NULL;
	guint _tmp3_ = 0U;
#line 50 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	g_return_val_if_fail (left != NULL, FALSE);
#line 50 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	g_return_val_if_fail (right != NULL, FALSE);
#line 52 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp0_ = left;
#line 52 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp1_ = _tmp0_->u;
#line 52 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp2_ = right;
#line 52 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp3_ = _tmp2_->u;
#line 52 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	result = _tmp1_ == _tmp3_;
#line 52 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	return result;
#line 337 "small-set.c"
}


static void uint_class_init (UIntClass * klass) {
#line 36 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	uint_parent_class = g_type_class_peek_parent (klass);
#line 36 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	G_OBJECT_CLASS (klass)->finalize = uint_finalize;
#line 346 "small-set.c"
}


static void uint_instance_init (UInt * self) {
}


static void uint_finalize (GObject* obj) {
	UInt * self;
#line 36 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_UINT, UInt);
#line 36 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	G_OBJECT_CLASS (uint_parent_class)->finalize (obj);
#line 360 "small-set.c"
}


GType uint_get_type (void) {
	static volatile gsize uint_type_id__volatile = 0;
	if (g_once_init_enter (&uint_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (UIntClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) uint_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (UInt), 0, (GInstanceInitFunc) uint_instance_init, NULL };
		GType uint_type_id;
		uint_type_id = g_type_register_static (G_TYPE_OBJECT, "UInt", &g_define_type_info, 0);
		g_once_init_leave (&uint_type_id__volatile, uint_type_id);
	}
	return uint_type_id__volatile;
}


static void __lambda3_ (SmallSetTests* self) {
#line 61 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	small_set_tests_test_objects (self, TRUE);
#line 379 "small-set.c"
}


static void ___lambda3__folks_test_case_test_method (gpointer self) {
#line 61 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	__lambda3_ ((SmallSetTests*) self);
#line 386 "small-set.c"
}


static void __lambda8_ (SmallSetTests* self) {
#line 62 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	small_set_tests_test_objects (self, FALSE);
#line 393 "small-set.c"
}


static void ___lambda8__folks_test_case_test_method (gpointer self) {
#line 62 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	__lambda8_ ((SmallSetTests*) self);
#line 400 "small-set.c"
}


static void __lambda9_ (SmallSetTests* self) {
#line 63 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	small_set_tests_test_iter (self, TRUE);
#line 407 "small-set.c"
}


static void ___lambda9__folks_test_case_test_method (gpointer self) {
#line 63 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	__lambda9_ ((SmallSetTests*) self);
#line 414 "small-set.c"
}


static void __lambda14_ (SmallSetTests* self) {
#line 64 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	small_set_tests_test_iter (self, FALSE);
#line 421 "small-set.c"
}


static void ___lambda14__folks_test_case_test_method (gpointer self) {
#line 64 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	__lambda14_ ((SmallSetTests*) self);
#line 428 "small-set.c"
}


static void __lambda15_ (SmallSetTests* self) {
#line 65 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	small_set_tests_test_readonly (self, TRUE);
#line 435 "small-set.c"
}


static void ___lambda15__folks_test_case_test_method (gpointer self) {
#line 65 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	__lambda15_ ((SmallSetTests*) self);
#line 442 "small-set.c"
}


static void __lambda18_ (SmallSetTests* self) {
#line 66 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	small_set_tests_test_readonly (self, FALSE);
#line 449 "small-set.c"
}


static void ___lambda18__folks_test_case_test_method (gpointer self) {
#line 66 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	__lambda18_ ((SmallSetTests*) self);
#line 456 "small-set.c"
}


static void __lambda19_ (SmallSetTests* self) {
#line 67 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	small_set_tests_test_direct (self, TRUE);
#line 463 "small-set.c"
}


static void ___lambda19__folks_test_case_test_method (gpointer self) {
#line 67 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	__lambda19_ ((SmallSetTests*) self);
#line 470 "small-set.c"
}


static void __lambda20_ (SmallSetTests* self) {
#line 68 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	small_set_tests_test_direct (self, FALSE);
#line 477 "small-set.c"
}


static void ___lambda20__folks_test_case_test_method (gpointer self) {
#line 68 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	__lambda20_ ((SmallSetTests*) self);
#line 484 "small-set.c"
}


static void __lambda21_ (SmallSetTests* self) {
#line 69 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	small_set_tests_test_strings (self, TRUE);
#line 491 "small-set.c"
}


static void ___lambda21__folks_test_case_test_method (gpointer self) {
#line 69 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	__lambda21_ ((SmallSetTests*) self);
#line 498 "small-set.c"
}


static void __lambda22_ (SmallSetTests* self) {
#line 70 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	small_set_tests_test_strings (self, FALSE);
#line 505 "small-set.c"
}


static void ___lambda22__folks_test_case_test_method (gpointer self) {
#line 70 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	__lambda22_ ((SmallSetTests*) self);
#line 512 "small-set.c"
}


static void _small_set_tests_test_cheating_folks_test_case_test_method (gpointer self) {
#line 71 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	small_set_tests_test_cheating ((SmallSetTests*) self);
#line 519 "small-set.c"
}


SmallSetTests* small_set_tests_construct (GType object_type) {
	SmallSetTests * self = NULL;
#line 60 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	self = (SmallSetTests*) folks_test_case_construct (object_type, "SmallSet");
#line 61 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "objects_hash", ___lambda3__folks_test_case_test_method, self);
#line 62 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "objects", ___lambda8__folks_test_case_test_method, self);
#line 63 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "iter_hash", ___lambda9__folks_test_case_test_method, self);
#line 64 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "iter", ___lambda14__folks_test_case_test_method, self);
#line 65 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "readonly_hash", ___lambda15__folks_test_case_test_method, self);
#line 66 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "readonly", ___lambda18__folks_test_case_test_method, self);
#line 67 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "direct_hash", ___lambda19__folks_test_case_test_method, self);
#line 68 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "direct", ___lambda20__folks_test_case_test_method, self);
#line 69 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "string_hash", ___lambda21__folks_test_case_test_method, self);
#line 70 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "string", ___lambda22__folks_test_case_test_method, self);
#line 71 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "cheating", _small_set_tests_test_cheating_folks_test_case_test_method, self);
#line 58 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	return self;
#line 551 "small-set.c"
}


SmallSetTests* small_set_tests_new (void) {
#line 58 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	return small_set_tests_construct (TYPE_SMALL_SET_TESTS);
#line 558 "small-set.c"
}


static Block1Data* block1_data_ref (Block1Data* _data1_) {
#line 74 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	g_atomic_int_inc (&_data1_->_ref_count_);
#line 74 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	return _data1_;
#line 567 "small-set.c"
}


static void block1_data_unref (void * _userdata_) {
	Block1Data* _data1_;
	_data1_ = (Block1Data*) _userdata_;
#line 74 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	if (g_atomic_int_dec_and_test (&_data1_->_ref_count_)) {
#line 576 "small-set.c"
		SmallSetTests* self;
#line 74 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		self = _data1_->self;
#line 74 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_g_object_unref0 (_data1_->ten);
#line 74 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_g_object_unref0 (self);
#line 74 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		g_slice_free (Block1Data, _data1_);
#line 586 "small-set.c"
	}
}


static guint _uint_hash_static_gee_hash_data_func (gconstpointer v, gpointer self) {
	guint result;
	result = uint_hash_static ((UInt*) v);
#line 76 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	return result;
#line 596 "small-set.c"
}


static gboolean _uint_equals_static_gee_equal_data_func (gconstpointer a, gconstpointer b, gpointer self) {
	gboolean result;
	result = uint_equals_static ((UInt*) a, (UInt*) b);
#line 76 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	return result;
#line 605 "small-set.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 79 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	return self ? g_object_ref (self) : NULL;
#line 612 "small-set.c"
}


static gboolean __lambda4_ (Block1Data* _data1_, UInt* obj) {
	SmallSetTests* self;
	gboolean result = FALSE;
	guint _tmp0_ = 0U;
	UInt* _tmp1_ = NULL;
	guint _tmp2_ = 0U;
#line 98 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	self = _data1_->self;
#line 98 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	g_return_val_if_fail (obj != NULL, FALSE);
#line 100 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp0_ = _data1_->sum;
#line 100 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp1_ = obj;
#line 100 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp2_ = _tmp1_->u;
#line 100 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_data1_->sum = _tmp0_ + _tmp2_;
#line 101 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	result = TRUE;
#line 101 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_g_object_unref0 (obj);
#line 101 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	return result;
#line 640 "small-set.c"
}


static gboolean ___lambda4__gee_forall_func (gpointer g, gpointer self) {
	gboolean result;
	result = __lambda4_ (self, (UInt*) g);
#line 98 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	return result;
#line 649 "small-set.c"
}


static gboolean __lambda5_ (Block1Data* _data1_, UInt* obj) {
	SmallSetTests* self;
	gboolean result = FALSE;
	guint _tmp0_ = 0U;
	UInt* _tmp1_ = NULL;
	guint _tmp2_ = 0U;
#line 112 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	self = _data1_->self;
#line 112 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	g_return_val_if_fail (obj != NULL, FALSE);
#line 114 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp0_ = _data1_->sum;
#line 114 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp1_ = obj;
#line 114 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp2_ = _tmp1_->u;
#line 114 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_data1_->sum = _tmp0_ + _tmp2_;
#line 115 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	result = FALSE;
#line 115 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_g_object_unref0 (obj);
#line 115 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	return result;
#line 677 "small-set.c"
}


static gboolean ___lambda5__gee_forall_func (gpointer g, gpointer self) {
	gboolean result;
	result = __lambda5_ (self, (UInt*) g);
#line 112 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	return result;
#line 686 "small-set.c"
}


static gboolean __lambda6_ (Block1Data* _data1_, UInt* obj) {
	SmallSetTests* self;
	gboolean result = FALSE;
	UInt* _tmp0_ = NULL;
	UInt* _tmp1_ = NULL;
#line 123 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	self = _data1_->self;
#line 123 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	g_return_val_if_fail (obj != NULL, FALSE);
#line 126 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp0_ = _data1_->ten;
#line 126 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp1_ = obj;
#line 126 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp0_ != _tmp1_, "ten != obj");
#line 127 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	result = TRUE;
#line 127 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_g_object_unref0 (obj);
#line 127 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	return result;
#line 711 "small-set.c"
}


static gboolean ___lambda6__gee_forall_func (gpointer g, gpointer self) {
	gboolean result;
	result = __lambda6_ (self, (UInt*) g);
#line 123 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	return result;
#line 720 "small-set.c"
}


static gboolean __lambda7_ (Block1Data* _data1_, UInt* obj) {
	SmallSetTests* self;
	gboolean result = FALSE;
	UInt* _tmp0_ = NULL;
	UInt* _tmp1_ = NULL;
#line 138 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	self = _data1_->self;
#line 138 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	g_return_val_if_fail (obj != NULL, FALSE);
#line 140 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp0_ = _data1_->ten;
#line 140 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp1_ = obj;
#line 140 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp0_ != _tmp1_, "ten != obj");
#line 141 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	result = TRUE;
#line 141 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_g_object_unref0 (obj);
#line 141 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	return result;
#line 745 "small-set.c"
}


static gboolean ___lambda7__gee_forall_func (gpointer g, gpointer self) {
	gboolean result;
	result = __lambda7_ (self, (UInt*) g);
#line 138 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	return result;
#line 754 "small-set.c"
}


void small_set_tests_test_objects (SmallSetTests* self, gboolean use_hash) {
	Block1Data* _data1_;
	FolksSmallSet* small = NULL;
	FolksSmallSet* _tmp0_ = NULL;
	GeeHashSet* hash = NULL;
	GeeHashSet* _tmp1_ = NULL;
	GeeSet* _tmp2_ = NULL;
	gboolean _tmp3_ = FALSE;
	GeeSet* objects = NULL;
	GeeSet* _tmp6_ = NULL;
	GeeSet* _tmp7_ = NULL;
	GeeSet* _tmp8_ = NULL;
	gboolean _tmp9_ = FALSE;
	gboolean _tmp10_ = FALSE;
	GeeSet* _tmp11_ = NULL;
	gint _tmp12_ = 0;
	gint _tmp13_ = 0;
	GeeSet* _tmp14_ = NULL;
	gboolean _tmp15_ = FALSE;
	gboolean _tmp16_ = FALSE;
	GeeSet* _tmp17_ = NULL;
	UInt* _tmp18_ = NULL;
	UInt* _tmp19_ = NULL;
	GeeSet* _tmp20_ = NULL;
	UInt* _tmp21_ = NULL;
	UInt* _tmp22_ = NULL;
	GeeSet* _tmp23_ = NULL;
	UInt* _tmp24_ = NULL;
	UInt* _tmp25_ = NULL;
	GeeSet* _tmp26_ = NULL;
	UInt* _tmp27_ = NULL;
	UInt* _tmp28_ = NULL;
	GeeSet* _tmp29_ = NULL;
	UInt* _tmp30_ = NULL;
	UInt* _tmp31_ = NULL;
	GeeSet* _tmp32_ = NULL;
	GeeSet* _tmp33_ = NULL;
	gboolean _tmp34_ = FALSE;
	gboolean _tmp35_ = FALSE;
	GeeSet* _tmp36_ = NULL;
	gboolean _tmp37_ = FALSE;
	gboolean _tmp38_ = FALSE;
	GeeSet* _tmp39_ = NULL;
	gint _tmp40_ = 0;
	gint _tmp41_ = 0;
	gboolean res = FALSE;
	GeeSet* _tmp42_ = NULL;
	gboolean _tmp43_ = FALSE;
	gboolean _tmp44_ = FALSE;
	guint _tmp46_ = 0U;
	GeeSet* _tmp47_ = NULL;
	gboolean _tmp48_ = FALSE;
	gboolean _tmp49_ = FALSE;
	gboolean _tmp50_ = FALSE;
	gboolean _tmp51_ = FALSE;
	gboolean _tmp52_ = FALSE;
	gboolean _tmp53_ = FALSE;
	guint _tmp54_ = 0U;
	UInt* _tmp59_ = NULL;
	GeeSet* _tmp60_ = NULL;
	GeeSet* _tmp61_ = NULL;
	UInt* _tmp62_ = NULL;
	gboolean _tmp63_ = FALSE;
	GeeSet* _tmp64_ = NULL;
	UInt* _tmp65_ = NULL;
	gboolean _tmp66_ = FALSE;
	GeeSet* _tmp67_ = NULL;
	UInt* _tmp68_ = NULL;
	gboolean _tmp69_ = FALSE;
	gboolean _tmp70_ = FALSE;
	GeeSet* _tmp71_ = NULL;
	gint _tmp72_ = 0;
	gint _tmp73_ = 0;
	GeeSet* _tmp74_ = NULL;
	GeeSet* _tmp75_ = NULL;
	UInt* _tmp76_ = NULL;
	guint _tmp86_ = 0U;
	GeeSet* _tmp87_ = NULL;
	UInt* _tmp88_ = NULL;
	gboolean _tmp89_ = FALSE;
	gboolean _tmp90_ = FALSE;
	guint _tmp100_ = 0U;
	GeeSet* _tmp101_ = NULL;
	GeeSet* _tmp102_ = NULL;
	gint _tmp103_ = 0;
	gint _tmp104_ = 0;
	GeeSet* _tmp105_ = NULL;
	gboolean _tmp106_ = FALSE;
	gboolean _tmp107_ = FALSE;
#line 74 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	g_return_if_fail (self != NULL);
#line 74 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_data1_ = g_slice_new0 (Block1Data);
#line 74 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_data1_->_ref_count_ = 1;
#line 74 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_data1_->self = g_object_ref (self);
#line 76 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp0_ = folks_small_set_new (TYPE_UINT, (GBoxedCopyFunc) g_object_ref, g_object_unref, _uint_hash_static_gee_hash_data_func, NULL, NULL, _uint_equals_static_gee_equal_data_func, NULL, NULL);
#line 76 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	small = _tmp0_;
#line 77 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp1_ = gee_hash_set_new (TYPE_UINT, (GBoxedCopyFunc) g_object_ref, g_object_unref, _uint_hash_static_gee_hash_data_func, NULL, NULL, _uint_equals_static_gee_equal_data_func, NULL, NULL);
#line 77 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	hash = _tmp1_;
#line 79 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp3_ = use_hash;
#line 79 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	if (_tmp3_) {
#line 867 "small-set.c"
		GeeHashSet* _tmp4_ = NULL;
#line 79 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp4_ = hash;
#line 79 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp2_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp4_, GEE_TYPE_SET) ? ((GeeSet*) _tmp4_) : NULL;
#line 873 "small-set.c"
	} else {
		FolksSmallSet* _tmp5_ = NULL;
#line 79 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp5_ = small;
#line 79 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp2_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp5_, GEE_TYPE_SET) ? ((GeeSet*) _tmp5_) : NULL;
#line 880 "small-set.c"
	}
#line 79 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp6_ = _g_object_ref0 (_tmp2_);
#line 79 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	objects = _tmp6_;
#line 81 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp7_ = objects;
#line 81 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp7_ != NULL, "objects != null");
#line 82 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp8_ = objects;
#line 82 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp9_ = gee_collection_get_read_only ((GeeCollection*) _tmp8_);
#line 82 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp10_ = _tmp9_;
#line 82 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_vala_assert (!_tmp10_, "!objects.read_only");
#line 83 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp11_ = objects;
#line 83 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp12_ = gee_collection_get_size ((GeeCollection*) _tmp11_);
#line 83 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp13_ = _tmp12_;
#line 83 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp13_ == 0, "objects.size == 0");
#line 84 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp14_ = objects;
#line 84 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp15_ = gee_collection_get_is_empty ((GeeCollection*) _tmp14_);
#line 84 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp16_ = _tmp15_;
#line 84 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp16_, "objects.is_empty");
#line 86 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp17_ = objects;
#line 86 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp18_ = uint_new ((guint) 10000);
#line 86 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp19_ = _tmp18_;
#line 86 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	gee_collection_add ((GeeCollection*) _tmp17_, _tmp19_);
#line 86 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_g_object_unref0 (_tmp19_);
#line 87 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp20_ = objects;
#line 87 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp21_ = uint_new ((guint) 1);
#line 87 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp22_ = _tmp21_;
#line 87 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	gee_collection_add ((GeeCollection*) _tmp20_, _tmp22_);
#line 87 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_g_object_unref0 (_tmp22_);
#line 88 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp23_ = objects;
#line 88 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp24_ = uint_new ((guint) 10);
#line 88 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp25_ = _tmp24_;
#line 88 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	gee_collection_add ((GeeCollection*) _tmp23_, _tmp25_);
#line 88 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_g_object_unref0 (_tmp25_);
#line 89 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp26_ = objects;
#line 89 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp27_ = uint_new ((guint) 100);
#line 89 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp28_ = _tmp27_;
#line 89 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	gee_collection_add ((GeeCollection*) _tmp26_, _tmp28_);
#line 89 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_g_object_unref0 (_tmp28_);
#line 90 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp29_ = objects;
#line 90 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp30_ = uint_new ((guint) 1000);
#line 90 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp31_ = _tmp30_;
#line 90 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	gee_collection_add ((GeeCollection*) _tmp29_, _tmp31_);
#line 90 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_g_object_unref0 (_tmp31_);
#line 92 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp32_ = objects;
#line 92 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp32_ != NULL, "objects != null");
#line 93 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp33_ = objects;
#line 93 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp34_ = gee_collection_get_read_only ((GeeCollection*) _tmp33_);
#line 93 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp35_ = _tmp34_;
#line 93 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_vala_assert (!_tmp35_, "!objects.read_only");
#line 94 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp36_ = objects;
#line 94 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp37_ = gee_collection_get_is_empty ((GeeCollection*) _tmp36_);
#line 94 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp38_ = _tmp37_;
#line 94 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_vala_assert (!_tmp38_, "!objects.is_empty");
#line 95 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp39_ = objects;
#line 95 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp40_ = gee_collection_get_size ((GeeCollection*) _tmp39_);
#line 95 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp41_ = _tmp40_;
#line 95 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp41_ == 5, "objects.size == 5");
#line 97 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_data1_->sum = (guint) 0;
#line 98 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp42_ = objects;
#line 98 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp43_ = gee_traversable_foreach ((GeeTraversable*) _tmp42_, ___lambda4__gee_forall_func, _data1_);
#line 98 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	res = _tmp43_;
#line 106 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp44_ = use_hash;
#line 106 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	if (!_tmp44_) {
#line 1004 "small-set.c"
		gboolean _tmp45_ = FALSE;
#line 107 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp45_ = res;
#line 107 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_vala_assert (_tmp45_ == TRUE, "res == true");
#line 1010 "small-set.c"
	}
#line 109 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp46_ = _data1_->sum;
#line 109 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp46_ == ((guint) 11111), "sum == 11111");
#line 111 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_data1_->sum = (guint) 0;
#line 112 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp47_ = objects;
#line 112 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp48_ = gee_traversable_foreach ((GeeTraversable*) _tmp47_, ___lambda5__gee_forall_func, _data1_);
#line 112 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	res = _tmp48_;
#line 117 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp49_ = res;
#line 117 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp49_ == FALSE, "res == false");
#line 118 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp54_ = _data1_->sum;
#line 118 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	if (_tmp54_ == ((guint) 1)) {
#line 118 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp53_ = TRUE;
#line 1034 "small-set.c"
	} else {
		guint _tmp55_ = 0U;
#line 118 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp55_ = _data1_->sum;
#line 118 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp53_ = _tmp55_ == ((guint) 10);
#line 1041 "small-set.c"
	}
#line 118 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	if (_tmp53_) {
#line 118 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp52_ = TRUE;
#line 1047 "small-set.c"
	} else {
		guint _tmp56_ = 0U;
#line 118 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp56_ = _data1_->sum;
#line 118 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp52_ = _tmp56_ == ((guint) 100);
#line 1054 "small-set.c"
	}
#line 118 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	if (_tmp52_) {
#line 118 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp51_ = TRUE;
#line 1060 "small-set.c"
	} else {
		guint _tmp57_ = 0U;
#line 118 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp57_ = _data1_->sum;
#line 118 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp51_ = _tmp57_ == ((guint) 1000);
#line 1067 "small-set.c"
	}
#line 118 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	if (_tmp51_) {
#line 118 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp50_ = TRUE;
#line 1073 "small-set.c"
	} else {
		guint _tmp58_ = 0U;
#line 119 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp58_ = _data1_->sum;
#line 119 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp50_ = _tmp58_ == ((guint) 10000);
#line 1080 "small-set.c"
	}
#line 118 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp50_, "sum == 1 || sum == 10 || sum == 100 || sum == 1000 ||         sum == 10000");
#line 121 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp59_ = uint_new ((guint) 10);
#line 121 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_data1_->ten = _tmp59_;
#line 123 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp60_ = objects;
#line 123 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	gee_traversable_foreach ((GeeTraversable*) _tmp60_, ___lambda6__gee_forall_func, _data1_);
#line 131 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp61_ = objects;
#line 131 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp62_ = _data1_->ten;
#line 131 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp63_ = gee_collection_contains ((GeeCollection*) _tmp61_, _tmp62_);
#line 131 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp63_, "objects.contains (ten)");
#line 133 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp64_ = objects;
#line 133 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp65_ = _data1_->ten;
#line 133 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp66_ = gee_collection_contains ((GeeCollection*) _tmp64_, _tmp65_);
#line 133 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp66_, "ten in objects");
#line 135 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp67_ = objects;
#line 135 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp68_ = _data1_->ten;
#line 135 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp69_ = gee_collection_add ((GeeCollection*) _tmp67_, _tmp68_);
#line 135 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	res = _tmp69_;
#line 136 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp70_ = res;
#line 136 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp70_ == FALSE, "res == false");
#line 137 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp71_ = objects;
#line 137 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp72_ = gee_collection_get_size ((GeeCollection*) _tmp71_);
#line 137 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp73_ = _tmp72_;
#line 137 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp73_ == 5, "objects.size == 5");
#line 138 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp74_ = objects;
#line 138 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	gee_traversable_foreach ((GeeTraversable*) _tmp74_, ___lambda7__gee_forall_func, _data1_);
#line 144 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp75_ = objects;
#line 144 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp76_ = _data1_->ten;
#line 144 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	gee_collection_remove ((GeeCollection*) _tmp75_, _tmp76_);
#line 147 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_data1_->sum = (guint) 0;
#line 1140 "small-set.c"
	{
		GeeIterator* _obj_it = NULL;
		GeeSet* _tmp77_ = NULL;
		GeeIterator* _tmp78_ = NULL;
#line 148 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp77_ = objects;
#line 148 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp78_ = gee_iterable_iterator ((GeeIterable*) _tmp77_);
#line 148 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_obj_it = _tmp78_;
#line 148 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		while (TRUE) {
#line 1153 "small-set.c"
			GeeIterator* _tmp79_ = NULL;
			gboolean _tmp80_ = FALSE;
			UInt* obj = NULL;
			GeeIterator* _tmp81_ = NULL;
			gpointer _tmp82_ = NULL;
			guint _tmp83_ = 0U;
			UInt* _tmp84_ = NULL;
			guint _tmp85_ = 0U;
#line 148 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
			_tmp79_ = _obj_it;
#line 148 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
			_tmp80_ = gee_iterator_next (_tmp79_);
#line 148 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
			if (!_tmp80_) {
#line 148 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
				break;
#line 1170 "small-set.c"
			}
#line 148 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
			_tmp81_ = _obj_it;
#line 148 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
			_tmp82_ = gee_iterator_get (_tmp81_);
#line 148 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
			obj = (UInt*) _tmp82_;
#line 149 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
			_tmp83_ = _data1_->sum;
#line 149 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
			_tmp84_ = obj;
#line 149 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
			_tmp85_ = _tmp84_->u;
#line 149 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
			_data1_->sum = _tmp83_ + _tmp85_;
#line 148 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
			_g_object_unref0 (obj);
#line 1188 "small-set.c"
		}
#line 148 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_g_object_unref0 (_obj_it);
#line 1192 "small-set.c"
	}
#line 150 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp86_ = _data1_->sum;
#line 150 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp86_ == ((guint) 11101), "sum == 11101");
#line 153 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp87_ = objects;
#line 153 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp88_ = _data1_->ten;
#line 153 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp89_ = gee_collection_add ((GeeCollection*) _tmp87_, _tmp88_);
#line 153 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	res = _tmp89_;
#line 154 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp90_ = res;
#line 154 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp90_ == TRUE, "res == true");
#line 156 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_data1_->sum = (guint) 0;
#line 1212 "small-set.c"
	{
		GeeIterator* _obj_it = NULL;
		GeeSet* _tmp91_ = NULL;
		GeeIterator* _tmp92_ = NULL;
#line 157 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp91_ = objects;
#line 157 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp92_ = gee_iterable_iterator ((GeeIterable*) _tmp91_);
#line 157 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_obj_it = _tmp92_;
#line 157 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		while (TRUE) {
#line 1225 "small-set.c"
			GeeIterator* _tmp93_ = NULL;
			gboolean _tmp94_ = FALSE;
			UInt* obj = NULL;
			GeeIterator* _tmp95_ = NULL;
			gpointer _tmp96_ = NULL;
			guint _tmp97_ = 0U;
			UInt* _tmp98_ = NULL;
			guint _tmp99_ = 0U;
#line 157 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
			_tmp93_ = _obj_it;
#line 157 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
			_tmp94_ = gee_iterator_next (_tmp93_);
#line 157 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
			if (!_tmp94_) {
#line 157 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
				break;
#line 1242 "small-set.c"
			}
#line 157 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
			_tmp95_ = _obj_it;
#line 157 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
			_tmp96_ = gee_iterator_get (_tmp95_);
#line 157 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
			obj = (UInt*) _tmp96_;
#line 158 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
			_tmp97_ = _data1_->sum;
#line 158 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
			_tmp98_ = obj;
#line 158 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
			_tmp99_ = _tmp98_->u;
#line 158 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
			_data1_->sum = _tmp97_ + _tmp99_;
#line 157 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
			_g_object_unref0 (obj);
#line 1260 "small-set.c"
		}
#line 157 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_g_object_unref0 (_obj_it);
#line 1264 "small-set.c"
	}
#line 159 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp100_ = _data1_->sum;
#line 159 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp100_ == ((guint) 11111), "sum == 11111");
#line 161 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp101_ = objects;
#line 161 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	gee_collection_clear ((GeeCollection*) _tmp101_);
#line 162 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp102_ = objects;
#line 162 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp103_ = gee_collection_get_size ((GeeCollection*) _tmp102_);
#line 162 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp104_ = _tmp103_;
#line 162 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp104_ == 0, "objects.size == 0");
#line 163 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp105_ = objects;
#line 163 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp106_ = gee_collection_get_is_empty ((GeeCollection*) _tmp105_);
#line 163 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp107_ = _tmp106_;
#line 163 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp107_, "objects.is_empty");
#line 1290 "small-set.c"
	{
		GeeIterator* _obj_it = NULL;
		GeeSet* _tmp108_ = NULL;
		GeeIterator* _tmp109_ = NULL;
#line 164 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp108_ = objects;
#line 164 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp109_ = gee_iterable_iterator ((GeeIterable*) _tmp108_);
#line 164 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_obj_it = _tmp109_;
#line 164 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		while (TRUE) {
#line 1303 "small-set.c"
			gboolean _tmp110_ = FALSE;
			UInt* obj = NULL;
			gpointer _tmp111_ = NULL;
#line 164 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
			_tmp110_ = gee_iterator_next (_obj_it);
#line 164 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
			if (!_tmp110_) {
#line 164 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
				break;
#line 1313 "small-set.c"
			}
#line 164 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
			_tmp111_ = gee_iterator_get (_obj_it);
#line 164 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
			obj = (UInt*) _tmp111_;
#line 165 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
			g_assert_not_reached ();
#line 164 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
			_g_object_unref0 (obj);
#line 1323 "small-set.c"
		}
#line 164 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_g_object_unref0 (_obj_it);
#line 1327 "small-set.c"
	}
#line 74 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_g_object_unref0 (objects);
#line 74 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_g_object_unref0 (hash);
#line 74 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_g_object_unref0 (small);
#line 74 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	block1_data_unref (_data1_);
#line 74 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_data1_ = NULL;
#line 1339 "small-set.c"
}


static Block2Data* block2_data_ref (Block2Data* _data2_) {
#line 168 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	g_atomic_int_inc (&_data2_->_ref_count_);
#line 168 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	return _data2_;
#line 1348 "small-set.c"
}


static void block2_data_unref (void * _userdata_) {
	Block2Data* _data2_;
	_data2_ = (Block2Data*) _userdata_;
#line 168 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	if (g_atomic_int_dec_and_test (&_data2_->_ref_count_)) {
#line 1357 "small-set.c"
		SmallSetTests* self;
#line 168 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		self = _data2_->self;
#line 168 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_g_object_unref0 (self);
#line 168 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		g_slice_free (Block2Data, _data2_);
#line 1365 "small-set.c"
	}
}


static gboolean __lambda10_ (Block2Data* _data2_, UInt* obj) {
	SmallSetTests* self;
	gboolean result = FALSE;
	guint _tmp0_ = 0U;
	UInt* _tmp1_ = NULL;
	guint _tmp2_ = 0U;
#line 219 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	self = _data2_->self;
#line 219 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	g_return_val_if_fail (obj != NULL, FALSE);
#line 221 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp0_ = _data2_->sum;
#line 221 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp1_ = obj;
#line 221 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp2_ = _tmp1_->u;
#line 221 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_data2_->sum = _tmp0_ + _tmp2_;
#line 222 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	result = TRUE;
#line 222 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_g_object_unref0 (obj);
#line 222 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	return result;
#line 1394 "small-set.c"
}


static gboolean ___lambda10__gee_forall_func (gpointer g, gpointer self) {
	gboolean result;
	result = __lambda10_ (self, (UInt*) g);
#line 219 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	return result;
#line 1403 "small-set.c"
}


static gboolean __lambda11_ (Block2Data* _data2_, UInt* obj) {
	SmallSetTests* self;
	gboolean result = FALSE;
	guint _tmp0_ = 0U;
	UInt* _tmp1_ = NULL;
	guint _tmp2_ = 0U;
#line 228 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	self = _data2_->self;
#line 228 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	g_return_val_if_fail (obj != NULL, FALSE);
#line 230 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp0_ = _data2_->sum;
#line 230 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp1_ = obj;
#line 230 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp2_ = _tmp1_->u;
#line 230 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_data2_->sum = _tmp0_ + _tmp2_;
#line 231 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	result = FALSE;
#line 231 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_g_object_unref0 (obj);
#line 231 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	return result;
#line 1431 "small-set.c"
}


static gboolean ___lambda11__gee_forall_func (gpointer g, gpointer self) {
	gboolean result;
	result = __lambda11_ (self, (UInt*) g);
#line 228 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	return result;
#line 1440 "small-set.c"
}


static gboolean __lambda12_ (Block2Data* _data2_, UInt* obj) {
	SmallSetTests* self;
	gboolean result = FALSE;
	guint _tmp0_ = 0U;
	UInt* _tmp1_ = NULL;
	guint _tmp2_ = 0U;
#line 247 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	self = _data2_->self;
#line 247 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	g_return_val_if_fail (obj != NULL, FALSE);
#line 249 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp0_ = _data2_->sum;
#line 249 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp1_ = obj;
#line 249 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp2_ = _tmp1_->u;
#line 249 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_data2_->sum = _tmp0_ + _tmp2_;
#line 250 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	result = TRUE;
#line 250 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_g_object_unref0 (obj);
#line 250 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	return result;
#line 1468 "small-set.c"
}


static gboolean ___lambda12__gee_forall_func (gpointer g, gpointer self) {
	gboolean result;
	result = __lambda12_ (self, (UInt*) g);
#line 247 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	return result;
#line 1477 "small-set.c"
}


static gboolean __lambda13_ (Block2Data* _data2_, UInt* obj) {
	SmallSetTests* self;
	gboolean result = FALSE;
	guint _tmp0_ = 0U;
#line 261 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	self = _data2_->self;
#line 261 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	g_return_val_if_fail (obj != NULL, FALSE);
#line 264 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp0_ = _data2_->sum;
#line 264 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_data2_->sum = _tmp0_ + 1;
#line 265 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	result = TRUE;
#line 265 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_g_object_unref0 (obj);
#line 265 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	return result;
#line 1499 "small-set.c"
}


static gboolean ___lambda13__gee_forall_func (gpointer g, gpointer self) {
	gboolean result;
	result = __lambda13_ (self, (UInt*) g);
#line 261 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	return result;
#line 1508 "small-set.c"
}


void small_set_tests_test_iter (SmallSetTests* self, gboolean use_hash) {
	Block2Data* _data2_;
	FolksSmallSet* small = NULL;
	FolksSmallSet* _tmp0_ = NULL;
	GeeHashSet* hash = NULL;
	GeeHashSet* _tmp1_ = NULL;
	GeeSet* _tmp2_ = NULL;
	gboolean _tmp3_ = FALSE;
	GeeSet* objects = NULL;
	GeeSet* _tmp6_ = NULL;
	GeeIterator* iter = NULL;
	GeeSet* _tmp7_ = NULL;
	GeeIterator* _tmp8_ = NULL;
	GeeIterator* _tmp9_ = NULL;
	gboolean _tmp10_ = FALSE;
	gboolean _tmp11_ = FALSE;
	GeeIterator* _tmp12_ = NULL;
	gboolean _tmp13_ = FALSE;
	gboolean _tmp14_ = FALSE;
	GeeIterator* _tmp15_ = NULL;
	gboolean _tmp16_ = FALSE;
	gboolean res = FALSE;
	GeeIterator* _tmp17_ = NULL;
	gboolean _tmp18_ = FALSE;
	gboolean _tmp19_ = FALSE;
	GeeIterator* _tmp20_ = NULL;
	gboolean _tmp21_ = FALSE;
	gboolean _tmp22_ = FALSE;
	GeeIterator* _tmp23_ = NULL;
	gboolean _tmp24_ = FALSE;
	GeeSet* _tmp25_ = NULL;
	UInt* _tmp26_ = NULL;
	UInt* _tmp27_ = NULL;
	GeeSet* _tmp28_ = NULL;
	UInt* _tmp29_ = NULL;
	UInt* _tmp30_ = NULL;
	GeeSet* _tmp31_ = NULL;
	UInt* _tmp32_ = NULL;
	UInt* _tmp33_ = NULL;
	GeeSet* _tmp34_ = NULL;
	UInt* _tmp35_ = NULL;
	UInt* _tmp36_ = NULL;
	GeeSet* _tmp37_ = NULL;
	UInt* _tmp38_ = NULL;
	UInt* _tmp39_ = NULL;
	GeeSet* _tmp40_ = NULL;
	gint _tmp41_ = 0;
	gint _tmp42_ = 0;
	GeeSet* _tmp43_ = NULL;
	GeeIterator* _tmp44_ = NULL;
	GeeIterator* _tmp45_ = NULL;
	gboolean _tmp46_ = FALSE;
	gboolean _tmp47_ = FALSE;
	GeeIterator* _tmp48_ = NULL;
	gboolean _tmp49_ = FALSE;
	gboolean _tmp50_ = FALSE;
	GeeIterator* _tmp51_ = NULL;
	gboolean _tmp52_ = FALSE;
	GeeIterator* _tmp53_ = NULL;
	gboolean _tmp54_ = FALSE;
	gboolean _tmp55_ = FALSE;
	GeeIterator* _tmp56_ = NULL;
	gboolean _tmp57_ = FALSE;
	gboolean _tmp58_ = FALSE;
	GeeIterator* _tmp59_ = NULL;
	gboolean _tmp60_ = FALSE;
	GeeIterator* _tmp61_ = NULL;
	GeeIterator* _tmp62_ = NULL;
	GeeIterator* _tmp63_ = NULL;
	GeeIterator* _tmp64_ = NULL;
	gboolean _tmp65_ = FALSE;
	gboolean _tmp66_ = FALSE;
	GeeIterator* _tmp67_ = NULL;
	gboolean _tmp68_ = FALSE;
	GeeIterator* _tmp69_ = NULL;
	GeeIterator* _tmp70_ = NULL;
	gboolean _tmp71_ = FALSE;
	gboolean _tmp72_ = FALSE;
	GeeIterator* _tmp73_ = NULL;
	gboolean _tmp74_ = FALSE;
	GeeIterator* _tmp75_ = NULL;
	gboolean _tmp76_ = FALSE;
	gboolean _tmp77_ = FALSE;
	GeeIterator* _tmp78_ = NULL;
	gboolean _tmp79_ = FALSE;
	gboolean _tmp80_ = FALSE;
	GeeIterator* _tmp81_ = NULL;
	gboolean _tmp82_ = FALSE;
	GeeSet* _tmp83_ = NULL;
	GeeIterator* _tmp84_ = NULL;
	GeeIterator* _tmp85_ = NULL;
	guint _tmp86_ = 0U;
	GeeSet* _tmp87_ = NULL;
	GeeIterator* _tmp88_ = NULL;
	GeeIterator* _tmp89_ = NULL;
	gboolean _tmp90_ = FALSE;
	gboolean _tmp91_ = FALSE;
	gboolean _tmp92_ = FALSE;
	gboolean _tmp93_ = FALSE;
	gboolean _tmp94_ = FALSE;
	gboolean _tmp95_ = FALSE;
	guint _tmp96_ = 0U;
	GeeSet* _tmp101_ = NULL;
	GeeIterator* _tmp102_ = NULL;
	GeeIterator* _tmp103_ = NULL;
	guint _tmp104_ = 0U;
	GeeIterator* _tmp105_ = NULL;
	gpointer _tmp106_ = NULL;
	UInt* _tmp107_ = NULL;
	guint _tmp108_ = 0U;
	GeeIterator* _tmp109_ = NULL;
	guint _tmp110_ = 0U;
	GeeIterator* _tmp111_ = NULL;
	gpointer _tmp112_ = NULL;
	UInt* _tmp113_ = NULL;
	guint _tmp114_ = 0U;
	GeeIterator* _tmp115_ = NULL;
	GeeIterator* _tmp116_ = NULL;
	guint _tmp117_ = 0U;
	GeeSet* _tmp118_ = NULL;
	GeeIterator* _tmp119_ = NULL;
	GeeIterator* _tmp120_ = NULL;
	GeeIterator* _tmp121_ = NULL;
	GeeIterator* _tmp122_ = NULL;
	GeeIterator* _tmp123_ = NULL;
	GeeIterator* _tmp124_ = NULL;
	GeeIterator* _tmp125_ = NULL;
	guint _tmp126_ = 0U;
	GeeSet* _tmp127_ = NULL;
	GeeIterator* _tmp128_ = NULL;
	GeeIterator* _tmp129_ = NULL;
	GeeIterator* _tmp130_ = NULL;
	gboolean _tmp131_ = FALSE;
	gboolean _tmp132_ = FALSE;
	UInt* removed = NULL;
	GeeIterator* _tmp133_ = NULL;
	gpointer _tmp134_ = NULL;
	GeeIterator* _tmp135_ = NULL;
	guint _tmp136_ = 0U;
	UInt* _tmp137_ = NULL;
	guint _tmp138_ = 0U;
	GeeIterator* _tmp139_ = NULL;
	gboolean _tmp140_ = FALSE;
	gboolean _tmp141_ = FALSE;
	guint _tmp149_ = 0U;
	GeeSet* _tmp150_ = NULL;
	UInt* _tmp151_ = NULL;
	GeeSet* _tmp152_ = NULL;
	GeeIterator* _tmp153_ = NULL;
	GeeIterator* _tmp154_ = NULL;
	guint _tmp155_ = 0U;
	GeeIterator* _tmp156_ = NULL;
	gpointer _tmp157_ = NULL;
	UInt* _tmp158_ = NULL;
	guint _tmp159_ = 0U;
	GeeIterator* _tmp160_ = NULL;
	guint _tmp161_ = 0U;
	GeeIterator* _tmp162_ = NULL;
	gpointer _tmp163_ = NULL;
	UInt* _tmp164_ = NULL;
	guint _tmp165_ = 0U;
	GeeIterator* _tmp166_ = NULL;
	GeeIterator* _tmp167_ = NULL;
	gboolean _tmp168_ = FALSE;
	gboolean _tmp169_ = FALSE;
	GeeIterator* _tmp170_ = NULL;
	gpointer _tmp171_ = NULL;
	GeeIterator* _tmp172_ = NULL;
	guint _tmp173_ = 0U;
	UInt* _tmp174_ = NULL;
	guint _tmp175_ = 0U;
	GeeIterator* _tmp176_ = NULL;
	gboolean _tmp177_ = FALSE;
	gboolean _tmp178_ = FALSE;
	guint _tmp186_ = 0U;
	GeeSet* _tmp187_ = NULL;
	UInt* _tmp188_ = NULL;
	GeeSet* _tmp189_ = NULL;
	GeeIterator* _tmp190_ = NULL;
	GeeIterator* _tmp191_ = NULL;
	GeeIterator* _tmp192_ = NULL;
	GeeIterator* _tmp193_ = NULL;
	GeeIterator* _tmp194_ = NULL;
	GeeIterator* _tmp195_ = NULL;
	GeeIterator* _tmp196_ = NULL;
	gboolean _tmp197_ = FALSE;
	gboolean _tmp198_ = FALSE;
	GeeIterator* _tmp199_ = NULL;
	gboolean _tmp200_ = FALSE;
	GeeIterator* _tmp201_ = NULL;
	gpointer _tmp202_ = NULL;
	GeeIterator* _tmp203_ = NULL;
	guint _tmp204_ = 0U;
	UInt* _tmp205_ = NULL;
	guint _tmp206_ = 0U;
	GeeIterator* _tmp207_ = NULL;
	gboolean _tmp208_ = FALSE;
	gboolean _tmp209_ = FALSE;
	GeeIterator* _tmp210_ = NULL;
	gboolean _tmp211_ = FALSE;
	guint _tmp221_ = 0U;
	GeeSet* _tmp222_ = NULL;
	UInt* _tmp223_ = NULL;
#line 168 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	g_return_if_fail (self != NULL);
#line 168 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_data2_ = g_slice_new0 (Block2Data);
#line 168 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_data2_->_ref_count_ = 1;
#line 168 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_data2_->self = g_object_ref (self);
#line 170 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp0_ = folks_small_set_new (TYPE_UINT, (GBoxedCopyFunc) g_object_ref, g_object_unref, _uint_hash_static_gee_hash_data_func, NULL, NULL, _uint_equals_static_gee_equal_data_func, NULL, NULL);
#line 170 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	small = _tmp0_;
#line 171 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp1_ = gee_hash_set_new (TYPE_UINT, (GBoxedCopyFunc) g_object_ref, g_object_unref, _uint_hash_static_gee_hash_data_func, NULL, NULL, _uint_equals_static_gee_equal_data_func, NULL, NULL);
#line 171 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	hash = _tmp1_;
#line 173 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp3_ = use_hash;
#line 173 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	if (_tmp3_) {
#line 1735 "small-set.c"
		GeeHashSet* _tmp4_ = NULL;
#line 173 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp4_ = hash;
#line 173 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp2_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp4_, GEE_TYPE_SET) ? ((GeeSet*) _tmp4_) : NULL;
#line 1741 "small-set.c"
	} else {
		FolksSmallSet* _tmp5_ = NULL;
#line 173 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp5_ = small;
#line 173 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp2_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp5_, GEE_TYPE_SET) ? ((GeeSet*) _tmp5_) : NULL;
#line 1748 "small-set.c"
	}
#line 173 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp6_ = _g_object_ref0 (_tmp2_);
#line 173 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	objects = _tmp6_;
#line 175 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp7_ = objects;
#line 175 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp8_ = gee_iterable_iterator ((GeeIterable*) _tmp7_);
#line 175 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	iter = _tmp8_;
#line 176 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp9_ = iter;
#line 176 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp10_ = gee_iterator_get_valid (_tmp9_);
#line 176 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp11_ = _tmp10_;
#line 176 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_vala_assert (!_tmp11_, "!iter.valid");
#line 177 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp12_ = iter;
#line 177 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp13_ = gee_iterator_get_read_only (_tmp12_);
#line 177 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp14_ = _tmp13_;
#line 177 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_vala_assert (!_tmp14_, "!iter.read_only");
#line 178 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp15_ = iter;
#line 178 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp16_ = gee_iterator_has_next (_tmp15_);
#line 178 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_vala_assert (!_tmp16_, "!iter.has_next ()");
#line 179 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp17_ = iter;
#line 179 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp18_ = gee_iterator_next (_tmp17_);
#line 179 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	res = _tmp18_;
#line 180 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp19_ = res;
#line 180 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_vala_assert (!_tmp19_, "!res");
#line 181 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp20_ = iter;
#line 181 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp21_ = gee_iterator_get_valid (_tmp20_);
#line 181 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp22_ = _tmp21_;
#line 181 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_vala_assert (!_tmp22_, "!iter.valid");
#line 182 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp23_ = iter;
#line 182 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp24_ = gee_iterator_has_next (_tmp23_);
#line 182 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_vala_assert (!_tmp24_, "!iter.has_next ()");
#line 184 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp25_ = objects;
#line 184 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp26_ = uint_new ((guint) 1);
#line 184 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp27_ = _tmp26_;
#line 184 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	gee_collection_add ((GeeCollection*) _tmp25_, _tmp27_);
#line 184 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_g_object_unref0 (_tmp27_);
#line 185 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp28_ = objects;
#line 185 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp29_ = uint_new ((guint) 10);
#line 185 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp30_ = _tmp29_;
#line 185 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	gee_collection_add ((GeeCollection*) _tmp28_, _tmp30_);
#line 185 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_g_object_unref0 (_tmp30_);
#line 186 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp31_ = objects;
#line 186 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp32_ = uint_new ((guint) 100);
#line 186 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp33_ = _tmp32_;
#line 186 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	gee_collection_add ((GeeCollection*) _tmp31_, _tmp33_);
#line 186 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_g_object_unref0 (_tmp33_);
#line 187 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp34_ = objects;
#line 187 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp35_ = uint_new ((guint) 1000);
#line 187 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp36_ = _tmp35_;
#line 187 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	gee_collection_add ((GeeCollection*) _tmp34_, _tmp36_);
#line 187 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_g_object_unref0 (_tmp36_);
#line 188 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp37_ = objects;
#line 188 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp38_ = uint_new ((guint) 10000);
#line 188 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp39_ = _tmp38_;
#line 188 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	gee_collection_add ((GeeCollection*) _tmp37_, _tmp39_);
#line 188 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_g_object_unref0 (_tmp39_);
#line 189 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp40_ = objects;
#line 189 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp41_ = gee_collection_get_size ((GeeCollection*) _tmp40_);
#line 189 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp42_ = _tmp41_;
#line 189 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp42_ == 5, "objects.size == 5");
#line 191 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp43_ = objects;
#line 191 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp44_ = gee_iterable_iterator ((GeeIterable*) _tmp43_);
#line 191 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_g_object_unref0 (iter);
#line 191 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	iter = _tmp44_;
#line 193 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp45_ = iter;
#line 193 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp46_ = gee_iterator_get_valid (_tmp45_);
#line 193 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp47_ = _tmp46_;
#line 193 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_vala_assert (!_tmp47_, "!iter.valid");
#line 194 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp48_ = iter;
#line 194 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp49_ = gee_iterator_get_read_only (_tmp48_);
#line 194 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp50_ = _tmp49_;
#line 194 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_vala_assert (!_tmp50_, "!iter.read_only");
#line 196 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp51_ = iter;
#line 196 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp52_ = gee_iterator_has_next (_tmp51_);
#line 196 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp52_, "iter.has_next ()");
#line 197 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp53_ = iter;
#line 197 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp54_ = gee_iterator_next (_tmp53_);
#line 197 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	res = _tmp54_;
#line 198 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp55_ = res;
#line 198 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp55_, "res");
#line 199 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp56_ = iter;
#line 199 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp57_ = gee_iterator_get_valid (_tmp56_);
#line 199 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp58_ = _tmp57_;
#line 199 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp58_, "iter.valid");
#line 200 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp59_ = iter;
#line 200 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp60_ = gee_iterator_has_next (_tmp59_);
#line 200 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp60_, "iter.has_next ()");
#line 202 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp61_ = iter;
#line 202 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	gee_iterator_next (_tmp61_);
#line 203 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp62_ = iter;
#line 203 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	gee_iterator_next (_tmp62_);
#line 204 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp63_ = iter;
#line 204 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	gee_iterator_next (_tmp63_);
#line 205 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp64_ = iter;
#line 205 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp65_ = gee_iterator_get_valid (_tmp64_);
#line 205 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp66_ = _tmp65_;
#line 205 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp66_, "iter.valid");
#line 206 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp67_ = iter;
#line 206 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp68_ = gee_iterator_has_next (_tmp67_);
#line 206 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp68_, "iter.has_next ()");
#line 207 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp69_ = iter;
#line 207 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	gee_iterator_next (_tmp69_);
#line 208 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp70_ = iter;
#line 208 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp71_ = gee_iterator_get_valid (_tmp70_);
#line 208 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp72_ = _tmp71_;
#line 208 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp72_, "iter.valid");
#line 209 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp73_ = iter;
#line 209 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp74_ = gee_iterator_has_next (_tmp73_);
#line 209 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_vala_assert (!_tmp74_, "!iter.has_next ()");
#line 210 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp75_ = iter;
#line 210 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp76_ = gee_iterator_next (_tmp75_);
#line 210 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	res = _tmp76_;
#line 211 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp77_ = res;
#line 211 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_vala_assert (!_tmp77_, "!res");
#line 212 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp78_ = iter;
#line 212 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp79_ = gee_iterator_get_valid (_tmp78_);
#line 212 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp80_ = _tmp79_;
#line 212 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp80_, "iter.valid");
#line 213 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp81_ = iter;
#line 213 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp82_ = gee_iterator_has_next (_tmp81_);
#line 213 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_vala_assert (!_tmp82_, "!iter.has_next ()");
#line 215 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp83_ = objects;
#line 215 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp84_ = gee_iterable_iterator ((GeeIterable*) _tmp83_);
#line 215 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_g_object_unref0 (iter);
#line 215 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	iter = _tmp84_;
#line 216 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_data2_->sum = (guint) 0;
#line 219 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp85_ = iter;
#line 219 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	gee_traversable_foreach ((GeeTraversable*) _tmp85_, ___lambda10__gee_forall_func, _data2_);
#line 224 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp86_ = _data2_->sum;
#line 224 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp86_ == ((guint) 11111), "sum == 11111");
#line 226 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_data2_->sum = (guint) 0;
#line 227 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp87_ = objects;
#line 227 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp88_ = gee_iterable_iterator ((GeeIterable*) _tmp87_);
#line 227 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_g_object_unref0 (iter);
#line 227 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	iter = _tmp88_;
#line 228 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp89_ = iter;
#line 228 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp90_ = gee_traversable_foreach ((GeeTraversable*) _tmp89_, ___lambda11__gee_forall_func, _data2_);
#line 228 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	res = _tmp90_;
#line 233 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp91_ = res;
#line 233 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp91_ == FALSE, "res == false");
#line 234 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp96_ = _data2_->sum;
#line 234 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	if (_tmp96_ == ((guint) 1)) {
#line 234 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp95_ = TRUE;
#line 2030 "small-set.c"
	} else {
		guint _tmp97_ = 0U;
#line 234 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp97_ = _data2_->sum;
#line 234 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp95_ = _tmp97_ == ((guint) 10);
#line 2037 "small-set.c"
	}
#line 234 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	if (_tmp95_) {
#line 234 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp94_ = TRUE;
#line 2043 "small-set.c"
	} else {
		guint _tmp98_ = 0U;
#line 234 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp98_ = _data2_->sum;
#line 234 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp94_ = _tmp98_ == ((guint) 100);
#line 2050 "small-set.c"
	}
#line 234 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	if (_tmp94_) {
#line 234 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp93_ = TRUE;
#line 2056 "small-set.c"
	} else {
		guint _tmp99_ = 0U;
#line 234 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp99_ = _data2_->sum;
#line 234 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp93_ = _tmp99_ == ((guint) 1000);
#line 2063 "small-set.c"
	}
#line 234 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	if (_tmp93_) {
#line 234 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp92_ = TRUE;
#line 2069 "small-set.c"
	} else {
		guint _tmp100_ = 0U;
#line 235 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp100_ = _data2_->sum;
#line 235 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp92_ = _tmp100_ == ((guint) 10000);
#line 2076 "small-set.c"
	}
#line 234 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp92_, "sum == 1 || sum == 10 || sum == 100 || sum == 1000 ||         sum == 10000");
#line 237 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_data2_->sum = (guint) 0;
#line 238 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp101_ = objects;
#line 238 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp102_ = gee_iterable_iterator ((GeeIterable*) _tmp101_);
#line 238 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_g_object_unref0 (iter);
#line 238 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	iter = _tmp102_;
#line 239 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp103_ = iter;
#line 239 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	gee_iterator_next (_tmp103_);
#line 240 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp104_ = _data2_->sum;
#line 240 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp105_ = iter;
#line 240 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp106_ = gee_iterator_get (_tmp105_);
#line 240 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp107_ = (UInt*) _tmp106_;
#line 240 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp108_ = _tmp107_->u;
#line 240 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_data2_->sum = _tmp104_ + _tmp108_;
#line 240 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_g_object_unref0 (_tmp107_);
#line 241 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp109_ = iter;
#line 241 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	gee_iterator_next (_tmp109_);
#line 242 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp110_ = _data2_->sum;
#line 242 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp111_ = iter;
#line 242 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp112_ = gee_iterator_get (_tmp111_);
#line 242 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp113_ = (UInt*) _tmp112_;
#line 242 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp114_ = _tmp113_->u;
#line 242 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_data2_->sum = _tmp110_ + _tmp114_;
#line 242 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_g_object_unref0 (_tmp113_);
#line 243 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp115_ = iter;
#line 243 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	gee_iterator_next (_tmp115_);
#line 247 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp116_ = iter;
#line 247 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	gee_traversable_foreach ((GeeTraversable*) _tmp116_, ___lambda12__gee_forall_func, _data2_);
#line 252 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp117_ = _data2_->sum;
#line 252 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp117_ == ((guint) 11111), "sum == 11111");
#line 254 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_data2_->sum = (guint) 0;
#line 255 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp118_ = objects;
#line 255 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp119_ = gee_iterable_iterator ((GeeIterable*) _tmp118_);
#line 255 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_g_object_unref0 (iter);
#line 255 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	iter = _tmp119_;
#line 256 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp120_ = iter;
#line 256 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	gee_iterator_next (_tmp120_);
#line 257 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp121_ = iter;
#line 257 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	gee_iterator_next (_tmp121_);
#line 258 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp122_ = iter;
#line 258 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	gee_iterator_next (_tmp122_);
#line 259 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp123_ = iter;
#line 259 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	gee_iterator_next (_tmp123_);
#line 260 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp124_ = iter;
#line 260 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	gee_iterator_next (_tmp124_);
#line 261 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp125_ = iter;
#line 261 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	gee_traversable_foreach ((GeeTraversable*) _tmp125_, ___lambda13__gee_forall_func, _data2_);
#line 267 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp126_ = _data2_->sum;
#line 267 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp126_ == ((guint) 1), "sum == 1");
#line 270 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_data2_->sum = (guint) 0;
#line 271 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp127_ = objects;
#line 271 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp128_ = gee_iterable_iterator ((GeeIterable*) _tmp127_);
#line 271 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_g_object_unref0 (iter);
#line 271 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	iter = _tmp128_;
#line 272 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp129_ = iter;
#line 272 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	gee_iterator_next (_tmp129_);
#line 273 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp130_ = iter;
#line 273 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp131_ = gee_iterator_get_valid (_tmp130_);
#line 273 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp132_ = _tmp131_;
#line 273 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp132_, "iter.valid");
#line 274 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp133_ = iter;
#line 274 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp134_ = gee_iterator_get (_tmp133_);
#line 274 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	removed = (UInt*) _tmp134_;
#line 275 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp135_ = iter;
#line 275 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	gee_iterator_remove (_tmp135_);
#line 276 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp136_ = _data2_->sum;
#line 276 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp137_ = removed;
#line 276 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp138_ = _tmp137_->u;
#line 276 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_data2_->sum = _tmp136_ + _tmp138_;
#line 277 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp139_ = iter;
#line 277 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp140_ = gee_iterator_get_valid (_tmp139_);
#line 277 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp141_ = _tmp140_;
#line 277 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_vala_assert (!_tmp141_, "!iter.valid");
#line 278 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	while (TRUE) {
#line 2226 "small-set.c"
		GeeIterator* _tmp142_ = NULL;
		gboolean _tmp143_ = FALSE;
		guint _tmp144_ = 0U;
		GeeIterator* _tmp145_ = NULL;
		gpointer _tmp146_ = NULL;
		UInt* _tmp147_ = NULL;
		guint _tmp148_ = 0U;
#line 278 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp142_ = iter;
#line 278 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp143_ = gee_iterator_next (_tmp142_);
#line 278 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		if (!_tmp143_) {
#line 278 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
			break;
#line 2242 "small-set.c"
		}
#line 279 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp144_ = _data2_->sum;
#line 279 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp145_ = iter;
#line 279 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp146_ = gee_iterator_get (_tmp145_);
#line 279 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp147_ = (UInt*) _tmp146_;
#line 279 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp148_ = _tmp147_->u;
#line 279 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_data2_->sum = _tmp144_ + _tmp148_;
#line 279 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_g_object_unref0 (_tmp147_);
#line 2258 "small-set.c"
	}
#line 280 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp149_ = _data2_->sum;
#line 280 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp149_ == ((guint) 11111), "sum == 11111");
#line 282 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp150_ = objects;
#line 282 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp151_ = removed;
#line 282 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	gee_collection_add ((GeeCollection*) _tmp150_, _tmp151_);
#line 285 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_data2_->sum = (guint) 0;
#line 286 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp152_ = objects;
#line 286 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp153_ = gee_iterable_iterator ((GeeIterable*) _tmp152_);
#line 286 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_g_object_unref0 (iter);
#line 286 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	iter = _tmp153_;
#line 287 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp154_ = iter;
#line 287 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	gee_iterator_next (_tmp154_);
#line 288 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp155_ = _data2_->sum;
#line 288 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp156_ = iter;
#line 288 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp157_ = gee_iterator_get (_tmp156_);
#line 288 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp158_ = (UInt*) _tmp157_;
#line 288 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp159_ = _tmp158_->u;
#line 288 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_data2_->sum = _tmp155_ + _tmp159_;
#line 288 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_g_object_unref0 (_tmp158_);
#line 289 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp160_ = iter;
#line 289 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	gee_iterator_next (_tmp160_);
#line 290 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp161_ = _data2_->sum;
#line 290 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp162_ = iter;
#line 290 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp163_ = gee_iterator_get (_tmp162_);
#line 290 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp164_ = (UInt*) _tmp163_;
#line 290 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp165_ = _tmp164_->u;
#line 290 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_data2_->sum = _tmp161_ + _tmp165_;
#line 290 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_g_object_unref0 (_tmp164_);
#line 291 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp166_ = iter;
#line 291 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	gee_iterator_next (_tmp166_);
#line 292 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp167_ = iter;
#line 292 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp168_ = gee_iterator_get_valid (_tmp167_);
#line 292 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp169_ = _tmp168_;
#line 292 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp169_, "iter.valid");
#line 293 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp170_ = iter;
#line 293 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp171_ = gee_iterator_get (_tmp170_);
#line 293 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_g_object_unref0 (removed);
#line 293 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	removed = (UInt*) _tmp171_;
#line 294 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp172_ = iter;
#line 294 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	gee_iterator_remove (_tmp172_);
#line 295 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp173_ = _data2_->sum;
#line 295 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp174_ = removed;
#line 295 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp175_ = _tmp174_->u;
#line 295 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_data2_->sum = _tmp173_ + _tmp175_;
#line 296 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp176_ = iter;
#line 296 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp177_ = gee_iterator_get_valid (_tmp176_);
#line 296 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp178_ = _tmp177_;
#line 296 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_vala_assert (!_tmp178_, "!iter.valid");
#line 297 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	while (TRUE) {
#line 2358 "small-set.c"
		GeeIterator* _tmp179_ = NULL;
		gboolean _tmp180_ = FALSE;
		guint _tmp181_ = 0U;
		GeeIterator* _tmp182_ = NULL;
		gpointer _tmp183_ = NULL;
		UInt* _tmp184_ = NULL;
		guint _tmp185_ = 0U;
#line 297 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp179_ = iter;
#line 297 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp180_ = gee_iterator_next (_tmp179_);
#line 297 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		if (!_tmp180_) {
#line 297 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
			break;
#line 2374 "small-set.c"
		}
#line 298 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp181_ = _data2_->sum;
#line 298 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp182_ = iter;
#line 298 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp183_ = gee_iterator_get (_tmp182_);
#line 298 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp184_ = (UInt*) _tmp183_;
#line 298 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp185_ = _tmp184_->u;
#line 298 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_data2_->sum = _tmp181_ + _tmp185_;
#line 298 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_g_object_unref0 (_tmp184_);
#line 2390 "small-set.c"
	}
#line 299 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp186_ = _data2_->sum;
#line 299 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp186_ == ((guint) 11111), "sum == 11111");
#line 301 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp187_ = objects;
#line 301 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp188_ = removed;
#line 301 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	gee_collection_add ((GeeCollection*) _tmp187_, _tmp188_);
#line 304 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_data2_->sum = (guint) 0;
#line 305 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp189_ = objects;
#line 305 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp190_ = gee_iterable_iterator ((GeeIterable*) _tmp189_);
#line 305 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_g_object_unref0 (iter);
#line 305 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	iter = _tmp190_;
#line 306 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp191_ = iter;
#line 306 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	gee_iterator_next (_tmp191_);
#line 307 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp192_ = iter;
#line 307 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	gee_iterator_next (_tmp192_);
#line 308 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp193_ = iter;
#line 308 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	gee_iterator_next (_tmp193_);
#line 309 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp194_ = iter;
#line 309 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	gee_iterator_next (_tmp194_);
#line 310 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp195_ = iter;
#line 310 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	gee_iterator_next (_tmp195_);
#line 311 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp196_ = iter;
#line 311 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp197_ = gee_iterator_get_valid (_tmp196_);
#line 311 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp198_ = _tmp197_;
#line 311 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp198_, "iter.valid");
#line 312 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp199_ = iter;
#line 312 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp200_ = gee_iterator_has_next (_tmp199_);
#line 312 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_vala_assert (!_tmp200_, "!iter.has_next ()");
#line 313 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp201_ = iter;
#line 313 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp202_ = gee_iterator_get (_tmp201_);
#line 313 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_g_object_unref0 (removed);
#line 313 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	removed = (UInt*) _tmp202_;
#line 314 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp203_ = iter;
#line 314 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	gee_iterator_remove (_tmp203_);
#line 315 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp204_ = _data2_->sum;
#line 315 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp205_ = removed;
#line 315 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp206_ = _tmp205_->u;
#line 315 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_data2_->sum = _tmp204_ + _tmp206_;
#line 316 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp207_ = iter;
#line 316 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp208_ = gee_iterator_get_valid (_tmp207_);
#line 316 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp209_ = _tmp208_;
#line 316 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_vala_assert (!_tmp209_, "!iter.valid");
#line 317 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp210_ = iter;
#line 317 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp211_ = gee_iterator_has_next (_tmp210_);
#line 317 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_vala_assert (!_tmp211_, "!iter.has_next ()");
#line 2480 "small-set.c"
	{
		GeeIterator* _obj_it = NULL;
		GeeSet* _tmp212_ = NULL;
		GeeIterator* _tmp213_ = NULL;
#line 318 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp212_ = objects;
#line 318 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp213_ = gee_iterable_iterator ((GeeIterable*) _tmp212_);
#line 318 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_obj_it = _tmp213_;
#line 318 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		while (TRUE) {
#line 2493 "small-set.c"
			GeeIterator* _tmp214_ = NULL;
			gboolean _tmp215_ = FALSE;
			UInt* obj = NULL;
			GeeIterator* _tmp216_ = NULL;
			gpointer _tmp217_ = NULL;
			guint _tmp218_ = 0U;
			UInt* _tmp219_ = NULL;
			guint _tmp220_ = 0U;
#line 318 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
			_tmp214_ = _obj_it;
#line 318 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
			_tmp215_ = gee_iterator_next (_tmp214_);
#line 318 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
			if (!_tmp215_) {
#line 318 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
				break;
#line 2510 "small-set.c"
			}
#line 318 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
			_tmp216_ = _obj_it;
#line 318 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
			_tmp217_ = gee_iterator_get (_tmp216_);
#line 318 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
			obj = (UInt*) _tmp217_;
#line 319 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
			_tmp218_ = _data2_->sum;
#line 319 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
			_tmp219_ = obj;
#line 319 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
			_tmp220_ = _tmp219_->u;
#line 319 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
			_data2_->sum = _tmp218_ + _tmp220_;
#line 318 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
			_g_object_unref0 (obj);
#line 2528 "small-set.c"
		}
#line 318 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_g_object_unref0 (_obj_it);
#line 2532 "small-set.c"
	}
#line 320 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp221_ = _data2_->sum;
#line 320 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp221_ == ((guint) 11111), "sum == 11111");
#line 322 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp222_ = objects;
#line 322 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp223_ = removed;
#line 322 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	gee_collection_add ((GeeCollection*) _tmp222_, _tmp223_);
#line 168 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_g_object_unref0 (removed);
#line 168 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_g_object_unref0 (iter);
#line 168 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_g_object_unref0 (objects);
#line 168 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_g_object_unref0 (hash);
#line 168 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_g_object_unref0 (small);
#line 168 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	block2_data_unref (_data2_);
#line 168 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_data2_ = NULL;
#line 2558 "small-set.c"
}


static Block3Data* block3_data_ref (Block3Data* _data3_) {
#line 325 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	g_atomic_int_inc (&_data3_->_ref_count_);
#line 325 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	return _data3_;
#line 2567 "small-set.c"
}


static void block3_data_unref (void * _userdata_) {
	Block3Data* _data3_;
	_data3_ = (Block3Data*) _userdata_;
#line 325 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	if (g_atomic_int_dec_and_test (&_data3_->_ref_count_)) {
#line 2576 "small-set.c"
		SmallSetTests* self;
#line 325 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		self = _data3_->self;
#line 325 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_g_object_unref0 (self);
#line 325 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		g_slice_free (Block3Data, _data3_);
#line 2584 "small-set.c"
	}
}


static gboolean __lambda16_ (Block3Data* _data3_, UInt* obj) {
	SmallSetTests* self;
	gboolean result = FALSE;
	guint _tmp0_ = 0U;
	UInt* _tmp1_ = NULL;
	guint _tmp2_ = 0U;
#line 343 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	self = _data3_->self;
#line 343 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	g_return_val_if_fail (obj != NULL, FALSE);
#line 345 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp0_ = _data3_->u;
#line 345 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp0_ == ((guint) 0), "u == 0");
#line 346 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp1_ = obj;
#line 346 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp2_ = _tmp1_->u;
#line 346 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_data3_->u = _tmp2_;
#line 347 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	result = TRUE;
#line 347 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_g_object_unref0 (obj);
#line 347 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	return result;
#line 2615 "small-set.c"
}


static gboolean ___lambda16__gee_forall_func (gpointer g, gpointer self) {
	gboolean result;
	result = __lambda16_ (self, (UInt*) g);
#line 343 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	return result;
#line 2624 "small-set.c"
}


static gboolean __lambda17_ (Block3Data* _data3_, UInt* obj) {
	SmallSetTests* self;
	gboolean result = FALSE;
	guint _tmp0_ = 0U;
	UInt* _tmp1_ = NULL;
	guint _tmp2_ = 0U;
#line 354 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	self = _data3_->self;
#line 354 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	g_return_val_if_fail (obj != NULL, FALSE);
#line 356 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp0_ = _data3_->u;
#line 356 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp0_ == ((guint) 0), "u == 0");
#line 357 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp1_ = obj;
#line 357 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp2_ = _tmp1_->u;
#line 357 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_data3_->u = _tmp2_;
#line 358 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	result = TRUE;
#line 358 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_g_object_unref0 (obj);
#line 358 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	return result;
#line 2654 "small-set.c"
}


static gboolean ___lambda17__gee_forall_func (gpointer g, gpointer self) {
	gboolean result;
	result = __lambda17_ (self, (UInt*) g);
#line 354 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	return result;
#line 2663 "small-set.c"
}


void small_set_tests_test_readonly (SmallSetTests* self, gboolean use_hash) {
	Block3Data* _data3_;
	FolksSmallSet* small = NULL;
	FolksSmallSet* _tmp0_ = NULL;
	GeeHashSet* hash = NULL;
	GeeHashSet* _tmp1_ = NULL;
	GeeSet* _tmp2_ = NULL;
	gboolean _tmp3_ = FALSE;
	GeeSet* objects = NULL;
	GeeSet* _tmp6_ = NULL;
	GeeSet* ro = NULL;
	GeeSet* _tmp7_ = NULL;
	GeeSet* _tmp8_ = NULL;
	GeeSet* _tmp9_ = NULL;
	GeeSet* _tmp10_ = NULL;
	GeeSet* _tmp11_ = NULL;
	GeeSet* _tmp12_ = NULL;
	GeeSet* _tmp13_ = NULL;
	gboolean _tmp14_ = FALSE;
	gboolean _tmp15_ = FALSE;
	GeeSet* _tmp16_ = NULL;
	gint _tmp17_ = 0;
	gint _tmp18_ = 0;
	GeeSet* _tmp19_ = NULL;
	UInt* _tmp20_ = NULL;
	UInt* _tmp21_ = NULL;
	GeeSet* _tmp22_ = NULL;
	gint _tmp23_ = 0;
	gint _tmp24_ = 0;
	GeeSet* _tmp25_ = NULL;
	gint _tmp26_ = 0;
	gint _tmp27_ = 0;
	GeeSet* _tmp28_ = NULL;
	guint _tmp29_ = 0U;
	GeeIterator* iter = NULL;
	GeeSet* _tmp30_ = NULL;
	GeeIterator* _tmp31_ = NULL;
	GeeIterator* _tmp32_ = NULL;
	gboolean _tmp33_ = FALSE;
	gboolean _tmp34_ = FALSE;
	GeeIterator* _tmp35_ = NULL;
	guint _tmp36_ = 0U;
	gboolean _tmp37_ = FALSE;
#line 325 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	g_return_if_fail (self != NULL);
#line 325 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_data3_ = g_slice_new0 (Block3Data);
#line 325 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_data3_->_ref_count_ = 1;
#line 325 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_data3_->self = g_object_ref (self);
#line 327 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp0_ = folks_small_set_new (TYPE_UINT, (GBoxedCopyFunc) g_object_ref, g_object_unref, _uint_hash_static_gee_hash_data_func, NULL, NULL, _uint_equals_static_gee_equal_data_func, NULL, NULL);
#line 327 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	small = _tmp0_;
#line 328 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp1_ = gee_hash_set_new (TYPE_UINT, (GBoxedCopyFunc) g_object_ref, g_object_unref, _uint_hash_static_gee_hash_data_func, NULL, NULL, _uint_equals_static_gee_equal_data_func, NULL, NULL);
#line 328 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	hash = _tmp1_;
#line 330 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp3_ = use_hash;
#line 330 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	if (_tmp3_) {
#line 2730 "small-set.c"
		GeeHashSet* _tmp4_ = NULL;
#line 330 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp4_ = hash;
#line 330 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp2_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp4_, GEE_TYPE_SET) ? ((GeeSet*) _tmp4_) : NULL;
#line 2736 "small-set.c"
	} else {
		FolksSmallSet* _tmp5_ = NULL;
#line 330 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp5_ = small;
#line 330 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp2_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp5_, GEE_TYPE_SET) ? ((GeeSet*) _tmp5_) : NULL;
#line 2743 "small-set.c"
	}
#line 330 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp6_ = _g_object_ref0 (_tmp2_);
#line 330 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	objects = _tmp6_;
#line 332 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp7_ = objects;
#line 332 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp8_ = gee_set_get_read_only_view (_tmp7_);
#line 332 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp9_ = _tmp8_;
#line 332 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	ro = _tmp9_;
#line 333 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp10_ = ro;
#line 333 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp10_ != NULL, "ro != null");
#line 334 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp11_ = ro;
#line 334 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp12_ = objects;
#line 334 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp11_ != _tmp12_, "ro != objects");
#line 335 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp13_ = ro;
#line 335 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp14_ = gee_collection_get_read_only ((GeeCollection*) _tmp13_);
#line 335 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp15_ = _tmp14_;
#line 335 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp15_, "ro.read_only");
#line 336 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp16_ = ro;
#line 336 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp17_ = gee_collection_get_size ((GeeCollection*) _tmp16_);
#line 336 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp18_ = _tmp17_;
#line 336 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp18_ == 0, "ro.size == 0");
#line 338 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp19_ = objects;
#line 338 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp20_ = uint_new ((guint) 23);
#line 338 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp21_ = _tmp20_;
#line 338 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	gee_collection_add ((GeeCollection*) _tmp19_, _tmp21_);
#line 338 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_g_object_unref0 (_tmp21_);
#line 339 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp22_ = objects;
#line 339 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp23_ = gee_collection_get_size ((GeeCollection*) _tmp22_);
#line 339 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp24_ = _tmp23_;
#line 339 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp24_ == 1, "objects.size == 1");
#line 340 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp25_ = ro;
#line 340 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp26_ = gee_collection_get_size ((GeeCollection*) _tmp25_);
#line 340 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp27_ = _tmp26_;
#line 340 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp27_ == 1, "ro.size == 1");
#line 342 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_data3_->u = (guint) 0;
#line 343 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp28_ = ro;
#line 343 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	gee_traversable_foreach ((GeeTraversable*) _tmp28_, ___lambda16__gee_forall_func, _data3_);
#line 349 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp29_ = _data3_->u;
#line 349 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp29_ == ((guint) 23), "u == 23");
#line 351 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp30_ = ro;
#line 351 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp31_ = gee_iterable_iterator ((GeeIterable*) _tmp30_);
#line 351 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	iter = _tmp31_;
#line 352 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp32_ = iter;
#line 352 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp33_ = gee_iterator_get_read_only (_tmp32_);
#line 352 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp34_ = _tmp33_;
#line 352 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp34_, "iter.read_only");
#line 353 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_data3_->u = (guint) 0;
#line 354 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp35_ = iter;
#line 354 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	gee_traversable_foreach ((GeeTraversable*) _tmp35_, ___lambda17__gee_forall_func, _data3_);
#line 360 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp36_ = _data3_->u;
#line 360 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp36_ == ((guint) 23), "u == 23");
#line 363 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp37_ = use_hash;
#line 363 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	if (!_tmp37_) {
#line 2847 "small-set.c"
		GeeSet* ro2 = NULL;
		GeeSet* _tmp38_ = NULL;
		GeeSet* _tmp39_ = NULL;
		GeeSet* _tmp40_ = NULL;
		GeeSet* _tmp41_ = NULL;
		GeeSet* _tmp42_ = NULL;
		GeeSet* _tmp43_ = NULL;
		GeeSet* _tmp44_ = NULL;
		GeeSet* _tmp45_ = NULL;
		GeeSet* _tmp46_ = NULL;
		GeeSet* _tmp47_ = NULL;
#line 366 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp38_ = objects;
#line 366 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp39_ = gee_set_get_read_only_view (_tmp38_);
#line 366 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp40_ = _tmp39_;
#line 366 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		ro2 = _tmp40_;
#line 367 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp41_ = ro;
#line 367 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp42_ = ro2;
#line 367 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_vala_assert (_tmp41_ != _tmp42_, "ro != ro2");
#line 370 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp43_ = ro;
#line 370 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp44_ = gee_set_get_read_only_view (_tmp43_);
#line 370 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp45_ = _tmp44_;
#line 370 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_g_object_unref0 (ro2);
#line 370 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		ro2 = _tmp45_;
#line 371 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp46_ = ro;
#line 371 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp47_ = ro2;
#line 371 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_vala_assert (_tmp46_ == _tmp47_, "ro == ro2");
#line 363 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_g_object_unref0 (ro2);
#line 2891 "small-set.c"
	}
#line 325 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_g_object_unref0 (iter);
#line 325 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_g_object_unref0 (ro);
#line 325 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_g_object_unref0 (objects);
#line 325 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_g_object_unref0 (hash);
#line 325 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_g_object_unref0 (small);
#line 325 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	block3_data_unref (_data3_);
#line 325 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_data3_ = NULL;
#line 2907 "small-set.c"
}


void small_set_tests_test_direct (SmallSetTests* self, gboolean use_hash) {
	FolksSmallSet* small = NULL;
	FolksSmallSet* _tmp0_ = NULL;
	GeeHashSet* hash = NULL;
	GeeHashSet* _tmp1_ = NULL;
	GeeSet* _tmp2_ = NULL;
	gboolean _tmp3_ = FALSE;
	GeeSet* objects = NULL;
	GeeSet* _tmp6_ = NULL;
	GeeSet* _tmp7_ = NULL;
	DirectEq* _tmp8_ = NULL;
	DirectEq* _tmp9_ = NULL;
	GeeSet* _tmp10_ = NULL;
	DirectEq* _tmp11_ = NULL;
	DirectEq* _tmp12_ = NULL;
	DirectEq* fortytwo = NULL;
	DirectEq* _tmp13_ = NULL;
	GeeSet* _tmp14_ = NULL;
	DirectEq* _tmp15_ = NULL;
	GeeSet* _tmp16_ = NULL;
	DirectEq* _tmp17_ = NULL;
	GeeSet* _tmp18_ = NULL;
	gint _tmp19_ = 0;
	gint _tmp20_ = 0;
	guint sum = 0U;
	guint _tmp30_ = 0U;
#line 375 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	g_return_if_fail (self != NULL);
#line 377 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp0_ = folks_small_set_new (TYPE_DIRECT_EQ, (GBoxedCopyFunc) g_object_ref, g_object_unref, NULL, NULL, NULL, NULL, NULL, NULL);
#line 377 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	small = _tmp0_;
#line 378 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp1_ = gee_hash_set_new (TYPE_DIRECT_EQ, (GBoxedCopyFunc) g_object_ref, g_object_unref, NULL, NULL, NULL, NULL, NULL, NULL);
#line 378 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	hash = _tmp1_;
#line 380 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp3_ = use_hash;
#line 380 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	if (_tmp3_) {
#line 2951 "small-set.c"
		GeeHashSet* _tmp4_ = NULL;
#line 381 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp4_ = hash;
#line 381 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp2_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp4_, GEE_TYPE_SET) ? ((GeeSet*) _tmp4_) : NULL;
#line 2957 "small-set.c"
	} else {
		FolksSmallSet* _tmp5_ = NULL;
#line 381 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp5_ = small;
#line 381 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp2_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp5_, GEE_TYPE_SET) ? ((GeeSet*) _tmp5_) : NULL;
#line 2964 "small-set.c"
	}
#line 380 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp6_ = _g_object_ref0 (_tmp2_);
#line 380 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	objects = _tmp6_;
#line 383 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp7_ = objects;
#line 383 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp8_ = direct_eq_new ((guint) 23);
#line 383 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp9_ = _tmp8_;
#line 383 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	gee_collection_add ((GeeCollection*) _tmp7_, _tmp9_);
#line 383 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_g_object_unref0 (_tmp9_);
#line 384 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp10_ = objects;
#line 384 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp11_ = direct_eq_new ((guint) 23);
#line 384 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp12_ = _tmp11_;
#line 384 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	gee_collection_add ((GeeCollection*) _tmp10_, _tmp12_);
#line 384 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_g_object_unref0 (_tmp12_);
#line 385 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp13_ = direct_eq_new ((guint) 42);
#line 385 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	fortytwo = _tmp13_;
#line 386 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp14_ = objects;
#line 386 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp15_ = fortytwo;
#line 386 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	gee_collection_add ((GeeCollection*) _tmp14_, _tmp15_);
#line 387 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp16_ = objects;
#line 387 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp17_ = fortytwo;
#line 387 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	gee_collection_add ((GeeCollection*) _tmp16_, _tmp17_);
#line 388 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp18_ = objects;
#line 388 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp19_ = gee_collection_get_size ((GeeCollection*) _tmp18_);
#line 388 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp20_ = _tmp19_;
#line 388 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp20_ == 3, "objects.size == 3");
#line 390 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	sum = (guint) 0;
#line 3016 "small-set.c"
	{
		GeeIterator* _obj_it = NULL;
		GeeSet* _tmp21_ = NULL;
		GeeIterator* _tmp22_ = NULL;
#line 391 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp21_ = objects;
#line 391 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp22_ = gee_iterable_iterator ((GeeIterable*) _tmp21_);
#line 391 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_obj_it = _tmp22_;
#line 391 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		while (TRUE) {
#line 3029 "small-set.c"
			GeeIterator* _tmp23_ = NULL;
			gboolean _tmp24_ = FALSE;
			DirectEq* obj = NULL;
			GeeIterator* _tmp25_ = NULL;
			gpointer _tmp26_ = NULL;
			guint _tmp27_ = 0U;
			DirectEq* _tmp28_ = NULL;
			guint _tmp29_ = 0U;
#line 391 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
			_tmp23_ = _obj_it;
#line 391 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
			_tmp24_ = gee_iterator_next (_tmp23_);
#line 391 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
			if (!_tmp24_) {
#line 391 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
				break;
#line 3046 "small-set.c"
			}
#line 391 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
			_tmp25_ = _obj_it;
#line 391 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
			_tmp26_ = gee_iterator_get (_tmp25_);
#line 391 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
			obj = (DirectEq*) _tmp26_;
#line 392 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
			_tmp27_ = sum;
#line 392 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
			_tmp28_ = obj;
#line 392 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
			_tmp29_ = _tmp28_->u;
#line 392 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
			sum = _tmp27_ + _tmp29_;
#line 391 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
			_g_object_unref0 (obj);
#line 3064 "small-set.c"
		}
#line 391 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_g_object_unref0 (_obj_it);
#line 3068 "small-set.c"
	}
#line 393 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp30_ = sum;
#line 393 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp30_ == ((guint) ((23 + 23) + 42)), "sum == 23 + 23 + 42");
#line 375 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_g_object_unref0 (fortytwo);
#line 375 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_g_object_unref0 (objects);
#line 375 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_g_object_unref0 (hash);
#line 375 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_g_object_unref0 (small);
#line 3082 "small-set.c"
}


void small_set_tests_test_strings (SmallSetTests* self, gboolean use_hash) {
	FolksSmallSet* small = NULL;
	FolksSmallSet* _tmp0_ = NULL;
	GeeHashSet* hash = NULL;
	GHashFunc _tmp1_ = NULL;
	GEqualFunc _tmp2_ = NULL;
	GeeHashSet* _tmp3_ = NULL;
	GeeSet* _tmp4_ = NULL;
	gboolean _tmp5_ = FALSE;
	GeeSet* strings = NULL;
	GeeSet* _tmp8_ = NULL;
	gint _tmp9_ = 0;
	gint _tmp10_ = 0;
#line 396 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	g_return_if_fail (self != NULL);
#line 398 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp0_ = folks_small_set_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL, NULL, NULL, NULL);
#line 398 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	small = _tmp0_;
#line 399 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp1_ = g_str_hash;
#line 399 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp2_ = g_str_equal;
#line 399 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp3_ = gee_hash_set_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, (GeeHashDataFunc) _tmp1_, NULL, NULL, (GeeEqualDataFunc) _tmp2_, NULL, NULL);
#line 399 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	hash = _tmp3_;
#line 402 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp5_ = use_hash;
#line 402 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	if (_tmp5_) {
#line 3117 "small-set.c"
		GeeHashSet* _tmp6_ = NULL;
#line 403 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp6_ = hash;
#line 403 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp4_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp6_, GEE_TYPE_SET) ? ((GeeSet*) _tmp6_) : NULL;
#line 3123 "small-set.c"
	} else {
		FolksSmallSet* _tmp7_ = NULL;
#line 403 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp7_ = small;
#line 403 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp4_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp7_, GEE_TYPE_SET) ? ((GeeSet*) _tmp7_) : NULL;
#line 3130 "small-set.c"
	}
#line 402 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp8_ = _g_object_ref0 (_tmp4_);
#line 402 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	strings = _tmp8_;
#line 405 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	gee_collection_add ((GeeCollection*) strings, "cheese");
#line 406 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	gee_collection_add ((GeeCollection*) strings, "cheese");
#line 407 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	gee_collection_add ((GeeCollection*) strings, "ham");
#line 408 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp9_ = gee_collection_get_size ((GeeCollection*) strings);
#line 408 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp10_ = _tmp9_;
#line 408 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp10_ == 2, "strings.size == 2");
#line 396 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_g_object_unref0 (strings);
#line 396 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_g_object_unref0 (hash);
#line 396 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_g_object_unref0 (small);
#line 3154 "small-set.c"
}


static Block4Data* block4_data_ref (Block4Data* _data4_) {
#line 411 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	g_atomic_int_inc (&_data4_->_ref_count_);
#line 411 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	return _data4_;
#line 3163 "small-set.c"
}


static void block4_data_unref (void * _userdata_) {
	Block4Data* _data4_;
	_data4_ = (Block4Data*) _userdata_;
#line 411 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	if (g_atomic_int_dec_and_test (&_data4_->_ref_count_)) {
#line 3172 "small-set.c"
		SmallSetTests* self;
#line 411 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		self = _data4_->self;
#line 411 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_g_object_unref0 (_data4_->small);
#line 411 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_g_object_unref0 (self);
#line 411 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		g_slice_free (Block4Data, _data4_);
#line 3182 "small-set.c"
	}
}


static gboolean __lambda23_ (Block4Data* _data4_, UInt* obj) {
	SmallSetTests* self;
	gboolean result = FALSE;
	FolksSmallSet* _tmp0_ = NULL;
	gint _tmp1_ = 0;
	gconstpointer _tmp2_ = NULL;
	UInt* _tmp3_ = NULL;
	gint _tmp4_ = 0;
#line 423 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	self = _data4_->self;
#line 423 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	g_return_val_if_fail (obj != NULL, FALSE);
#line 426 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp0_ = _data4_->small;
#line 426 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp1_ = _data4_->i;
#line 426 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp2_ = folks_small_set_get (_tmp0_, _tmp1_);
#line 426 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp3_ = obj;
#line 426 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_vala_assert (((UInt*) _tmp2_) == _tmp3_, "small[i] == obj");
#line 427 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp4_ = _data4_->i;
#line 427 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_data4_->i = _tmp4_ + 1;
#line 428 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	result = TRUE;
#line 428 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_g_object_unref0 (obj);
#line 428 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	return result;
#line 3219 "small-set.c"
}


static gboolean ___lambda23__gee_forall_func (gpointer g, gpointer self) {
	gboolean result;
	result = __lambda23_ (self, (UInt*) g);
#line 423 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	return result;
#line 3228 "small-set.c"
}


void small_set_tests_test_cheating (SmallSetTests* self) {
	Block4Data* _data4_;
	FolksSmallSet* _tmp0_ = NULL;
	GeeSet* set_ = NULL;
	FolksSmallSet* _tmp1_ = NULL;
	GeeSet* _tmp2_ = NULL;
	FolksSmallSet* _tmp3_ = NULL;
	UInt* _tmp4_ = NULL;
	UInt* _tmp5_ = NULL;
	FolksSmallSet* _tmp6_ = NULL;
	UInt* _tmp7_ = NULL;
	UInt* _tmp8_ = NULL;
	FolksSmallSet* _tmp9_ = NULL;
	UInt* _tmp10_ = NULL;
	UInt* _tmp11_ = NULL;
	FolksSmallSet* _tmp12_ = NULL;
	UInt* _tmp13_ = NULL;
	UInt* _tmp14_ = NULL;
	FolksSmallSet* _tmp15_ = NULL;
	UInt* _tmp16_ = NULL;
	UInt* _tmp17_ = NULL;
	GeeSet* _tmp18_ = NULL;
	GeeIterator* _tmp19_ = NULL;
	GeeIterator* _tmp20_ = NULL;
	gint _tmp21_ = 0;
	guint sum = 0U;
	guint _tmp31_ = 0U;
	guint _tmp46_ = 0U;
#line 411 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	g_return_if_fail (self != NULL);
#line 411 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_data4_ = g_slice_new0 (Block4Data);
#line 411 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_data4_->_ref_count_ = 1;
#line 411 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_data4_->self = g_object_ref (self);
#line 413 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp0_ = folks_small_set_new (TYPE_UINT, (GBoxedCopyFunc) g_object_ref, g_object_unref, _uint_hash_static_gee_hash_data_func, NULL, NULL, _uint_equals_static_gee_equal_data_func, NULL, NULL);
#line 413 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_data4_->small = _tmp0_;
#line 414 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp1_ = _data4_->small;
#line 414 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp2_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, GEE_TYPE_SET) ? ((GeeSet*) _tmp1_) : NULL, GEE_TYPE_SET, GeeSet));
#line 414 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	set_ = _tmp2_;
#line 416 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp3_ = _data4_->small;
#line 416 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp4_ = uint_new ((guint) 1);
#line 416 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp5_ = _tmp4_;
#line 416 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp3_, _tmp5_);
#line 416 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_g_object_unref0 (_tmp5_);
#line 417 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp6_ = _data4_->small;
#line 417 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp7_ = uint_new ((guint) 10);
#line 417 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp8_ = _tmp7_;
#line 417 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp6_, _tmp8_);
#line 417 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_g_object_unref0 (_tmp8_);
#line 418 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp9_ = _data4_->small;
#line 418 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp10_ = uint_new ((guint) 100);
#line 418 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp11_ = _tmp10_;
#line 418 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp9_, _tmp11_);
#line 418 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_g_object_unref0 (_tmp11_);
#line 419 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp12_ = _data4_->small;
#line 419 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp13_ = uint_new ((guint) 1000);
#line 419 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp14_ = _tmp13_;
#line 419 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp12_, _tmp14_);
#line 419 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_g_object_unref0 (_tmp14_);
#line 420 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp15_ = _data4_->small;
#line 420 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp16_ = uint_new ((guint) 10000);
#line 420 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp17_ = _tmp16_;
#line 420 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp15_, _tmp17_);
#line 420 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_g_object_unref0 (_tmp17_);
#line 422 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_data4_->i = 0;
#line 423 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp18_ = set_;
#line 423 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp19_ = gee_iterable_iterator ((GeeIterable*) _tmp18_);
#line 423 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp20_ = _tmp19_;
#line 423 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	gee_traversable_foreach ((GeeTraversable*) _tmp20_, ___lambda23__gee_forall_func, _data4_);
#line 423 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_g_object_unref0 (_tmp20_);
#line 430 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp21_ = _data4_->i;
#line 430 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp21_ == 5, "i == 5");
#line 434 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	sum = (guint) 0;
#line 3346 "small-set.c"
	{
		GeeIterator* _obj_it = NULL;
		GeeSet* _tmp22_ = NULL;
		GeeIterator* _tmp23_ = NULL;
#line 435 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp22_ = set_;
#line 435 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp23_ = gee_iterable_iterator ((GeeIterable*) _tmp22_);
#line 435 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_obj_it = _tmp23_;
#line 435 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		while (TRUE) {
#line 3359 "small-set.c"
			GeeIterator* _tmp24_ = NULL;
			gboolean _tmp25_ = FALSE;
			UInt* obj = NULL;
			GeeIterator* _tmp26_ = NULL;
			gpointer _tmp27_ = NULL;
			guint _tmp28_ = 0U;
			UInt* _tmp29_ = NULL;
			guint _tmp30_ = 0U;
#line 435 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
			_tmp24_ = _obj_it;
#line 435 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
			_tmp25_ = gee_iterator_next (_tmp24_);
#line 435 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
			if (!_tmp25_) {
#line 435 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
				break;
#line 3376 "small-set.c"
			}
#line 435 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
			_tmp26_ = _obj_it;
#line 435 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
			_tmp27_ = gee_iterator_get (_tmp26_);
#line 435 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
			obj = (UInt*) _tmp27_;
#line 436 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
			_tmp28_ = sum;
#line 436 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
			_tmp29_ = obj;
#line 436 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
			_tmp30_ = _tmp29_->u;
#line 436 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
			sum = _tmp28_ + _tmp30_;
#line 435 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
			_g_object_unref0 (obj);
#line 3394 "small-set.c"
		}
#line 435 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_g_object_unref0 (_obj_it);
#line 3398 "small-set.c"
	}
#line 437 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp31_ = sum;
#line 437 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp31_ == ((guint) 11111), "sum == 11111");
#line 441 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	sum = (guint) 0;
#line 3406 "small-set.c"
	{
		FolksSmallSet* _obj_list = NULL;
		FolksSmallSet* _tmp32_ = NULL;
		FolksSmallSet* _tmp33_ = NULL;
		gint _obj_size = 0;
		FolksSmallSet* _tmp34_ = NULL;
		gint _tmp35_ = 0;
		gint _tmp36_ = 0;
		gint _obj_index = 0;
#line 442 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp32_ = _data4_->small;
#line 442 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp33_ = _g_object_ref0 (_tmp32_);
#line 442 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_obj_list = _tmp33_;
#line 442 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp34_ = _obj_list;
#line 442 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp35_ = gee_collection_get_size ((GeeCollection*) _tmp34_);
#line 442 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_tmp36_ = _tmp35_;
#line 442 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_obj_size = _tmp36_;
#line 442 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_obj_index = -1;
#line 442 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		while (TRUE) {
#line 3434 "small-set.c"
			gint _tmp37_ = 0;
			gint _tmp38_ = 0;
			gint _tmp39_ = 0;
			UInt* obj = NULL;
			FolksSmallSet* _tmp40_ = NULL;
			gint _tmp41_ = 0;
			gconstpointer _tmp42_ = NULL;
			guint _tmp43_ = 0U;
			UInt* _tmp44_ = NULL;
			guint _tmp45_ = 0U;
#line 442 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
			_tmp37_ = _obj_index;
#line 442 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
			_obj_index = _tmp37_ + 1;
#line 442 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
			_tmp38_ = _obj_index;
#line 442 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
			_tmp39_ = _obj_size;
#line 442 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
			if (!(_tmp38_ < _tmp39_)) {
#line 442 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
				break;
#line 3457 "small-set.c"
			}
#line 442 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
			_tmp40_ = _obj_list;
#line 442 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
			_tmp41_ = _obj_index;
#line 442 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
			_tmp42_ = folks_small_set_get (_tmp40_, _tmp41_);
#line 442 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
			obj = (UInt*) _tmp42_;
#line 443 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
			_tmp43_ = sum;
#line 443 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
			_tmp44_ = obj;
#line 443 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
			_tmp45_ = _tmp44_->u;
#line 443 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
			sum = _tmp43_ + _tmp45_;
#line 3475 "small-set.c"
		}
#line 442 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
		_g_object_unref0 (_obj_list);
#line 3479 "small-set.c"
	}
#line 444 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp46_ = sum;
#line 444 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp46_ == ((guint) 11111), "sum == 11111");
#line 411 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_g_object_unref0 (set_);
#line 411 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	block4_data_unref (_data4_);
#line 411 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_data4_ = NULL;
#line 3491 "small-set.c"
}


static void small_set_tests_class_init (SmallSetTestsClass * klass) {
#line 56 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	small_set_tests_parent_class = g_type_class_peek_parent (klass);
#line 3498 "small-set.c"
}


static void small_set_tests_instance_init (SmallSetTests * self) {
}


GType small_set_tests_get_type (void) {
	static volatile gsize small_set_tests_type_id__volatile = 0;
	if (g_once_init_enter (&small_set_tests_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SmallSetTestsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) small_set_tests_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SmallSetTests), 0, (GInstanceInitFunc) small_set_tests_instance_init, NULL };
		GType small_set_tests_type_id;
		small_set_tests_type_id = g_type_register_static (FOLKS_TYPE_TEST_CASE, "SmallSetTests", &g_define_type_info, 0);
		g_once_init_leave (&small_set_tests_type_id__volatile, small_set_tests_type_id);
	}
	return small_set_tests_type_id__volatile;
}


gint _vala_main (gchar** args, int args_length1) {
	gint result = 0;
	SmallSetTests* tests = NULL;
	SmallSetTests* _tmp0_ = NULL;
#line 450 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	g_test_init (&args_length1, &args, NULL);
#line 452 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_tmp0_ = small_set_tests_new ();
#line 452 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	tests = _tmp0_;
#line 453 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	folks_test_case_register ((FolksTestCase*) tests);
#line 454 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	g_test_run ();
#line 455 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	folks_test_case_final_tear_down ((FolksTestCase*) tests);
#line 457 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	result = 0;
#line 457 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	_g_object_unref0 (tests);
#line 457 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	return result;
#line 3540 "small-set.c"
}


int main (int argc, char ** argv) {
#if !GLIB_CHECK_VERSION (2,35,0)
	g_type_init ();
#endif
#line 448 "/opt/gnome3/source/folks/tests/folks/small-set.vala"
	return _vala_main (argv, argc);
#line 3550 "small-set.c"
}



